<?php

/**
 * Helper de formatação de data e hora
 * Utiliza a Classe Carbon para formatação
 *
 * @param [type] $value
 * @param string $formato
 * @return void
 */
function formataDataHora($value, $formato = 'd/m/Y')
{
    return Carbon\Carbon::parse($value)->format($formato);
}

/**
 * Formata perfil do usuário
 *
 * @param integer $tipoPerfil
 * @return void
 */
function getPerfil(int $tipoPerfil)
{
    switch ($tipoPerfil) {
        case 1:
            return "Administrador";
            break;
        case 6:
            return "Tutores";
            break;
        case 7:
            return "Coord. Presencial";
            break;
        case 8:
            return "Coordenador EAD";
            break;

        default:
            return "N/d";
            break;
    }
}

/**
 * Formata Status da Matrícula
 *
 * @param [type] $val
 * @return void
 */
function getStatusMatricula($val)
{
    switch ($val) {
        case 0:
            return '<span class="task-cat grey darken-3">Inativo</span>';
            break;
        case 1:
            return '<span class="task-cat blue darken-3">Ativo</span>';
            break;
        case 2:
            return '<span class="task-cat red darken-3">Cancelada</span>';
            break;
        case 3:
            return '<span class="task-cat yellow darken-1">Transferido</span>';
            break;
        case 4:
            return '<span class="task-cat grey lighten-3">Ausente</span>';
            break;
        case 5:
            return '<span class="task-cat orange darken-3">Evadido</span>';
            break;
        default:
            return '';
            break;
    }
}

/**
 * Formata status padrão de ativo e inativo
 *
 * @param [type] $sts
 * @return void
 */
function statusPadrao($sts)
{

    switch ($sts) {
        case 0:
            return '<span class="task-cat yellow darken-3">Inativo</span>';
            break;
        case 1:
            return '<span class="task-cat teal darken-2">Ativo</span>';
            break;
        default:
            return 'N/d';
            break;
    }
}

/**
 * Padroniza icone de recurso
 *
 * @param [type] $tipoRecurso
 * @return void
 */
function getIconRecurso($tipoRecurso)
{
    switch ($tipoRecurso) {
        case 1: // BANNER
            return '<i class="large mdi-image-image circle red"></i>';
            break;
        case 2: // VIDEO
            return '<i class="large mdi-av-videocam circle yellow"></i>';
            break;
        case 3: // ARQUIVOS
            return '<i class="large mdi-editor-attach-file circle blue"></i>';
            break;
        case 4: // PÁGINAS
            return '<i class="large mdi-av-web circle purple"></i>';
            break;
        case 5: // ATIVIDADES
            return '<i class="large mdi-action-list circle orange"></i>';
            break;
        case 6: // LINK
            return '<i class="large mdi-editor-insert-link circle grey"></i>';
            break;
        case 7: // FORUM
            return '<i class="large mdi-communication-message circle green darken darken-3"></i>';
            break;
        default: // NÃO ENCONTRADO
            return '<i class="large mdi-communication-message circle red"></i>';
            break;
    }
}

/**
 * Exibe ícones de recursos na road do aluno
 *
 * @param [type] $tipoRecurso
 * @return void
 */
function getIconRecursoRoad($tipoRecurso)
{
    switch ($tipoRecurso) {
        case 1: // BANNER
            return '<div class="cd-timeline__img cd-timeline__img--movie red darken-1" style="color: #fff">
                        <i class="material-icons">image</i>
                    </div> <!-- cd-timeline__img -->';
            break;
        case 2: // VIDEO
            return '<div class="cd-timeline__img cd-timeline__img--movie yellow darken-1" style="color: #fff">
                        <i class="material-icons">ondemand_video</i>
                    </div> <!-- cd-timeline__img -->';
            break;
        case 3: // ARQUIVOS
            return '<div class="cd-timeline__img cd-timeline__img--movie blue darken-1" style="color: #fff">
                        <i class="material-icons">attach_file</i>
                    </div> <!-- cd-timeline__img -->';
            break;
        case 4: // PÁGINAS
            return '<div class="cd-timeline__img cd-timeline__img--movie purple darken-1" style="color: #fff">
                        <i class="material-icons">web</i>
                    </div> <!-- cd-timeline__img -->';
            break;
        case 5: // ATIVIDADES
            return '<div class="cd-timeline__img cd-timeline__img--movie orange darken-1" style="color: #fff">
                        <i class="material-icons">format_list_numbered</i>
                    </div> <!-- cd-timeline__img -->';
            break;
        case 6: // LINK
            return '<div class="cd-timeline__img cd-timeline__img--movie grey darken-1" style="color: #fff">
                        <i class="material-icons">link</i>
                    </div> <!-- cd-timeline__img -->';
            break;
        case 7: // FORUM
            return '<div class="cd-timeline__img cd-timeline__img--movie green darken-1" style="color: #fff">
                        <i class="material-icons">insert_comment</i>
                    </div> <!-- cd-timeline__img -->';
            break;
        default: // NÃO ENCONTRADO
            return '<div class="cd-timeline__img cd-timeline__img--movie red" style="color: #fff">
                        <i class="material-icons">sentiment_very_dissatisfied</i>
                    </div> <!-- cd-timeline__img -->';
            break;
    }
}

/**
 * Calcula periodo de duas datas baseados na qtde de dias
 *
 * @param [type] $data
 * @param [type] $qtdeDias
 * @return void
 */
function calculoDataPeriodo($dataCalculo, $qtdeDias)
{
    $dataInicio = date('Y-m-d', strtotime('-' . $qtdeDias . ' days', strtotime($dataCalculo)));
    $dataFim = date('Y-m-d', strtotime('+ 30 days', strtotime($dataInicio)));

    return formataDataHora($dataInicio, 'd/m/Y') . " à " . formataDataHora($dataFim, 'd/m/Y');
}

function calendarioAcademico($dataMatricula, $dias)
{
    $dataBase = date('Y-m-d', strtotime("+{$dias} days", strtotime($dataMatricula)));
    return $dataBase;
}

/**
 * Formata liberação de material.
 *
 * @param int $tipo
 * @return string
 */
function getLiberaMaterial(int $tipo = null)
{
    switch ($tipo) {
        case 1:
            $tipoLiberacao = "Data de Inicio da Turma.";
            break;
        case 2:
            $tipoLiberacao = "Data de Matrícula do Aluno.";
            break;
        default:
            $tipoLiberacao = "Não Definido.";
            break;
    }

    return $tipoLiberacao;
}

/**
 * Função que valida as datas de vencimentos de pazos, para que elas não caiam em finais de semana
 * $dtVcto = yyyy-mm-dd
 *
 * @param [type] $dtVcto
 * @return void
 */
function validaVcto($dtVcto)
{
    // desmembra data
    $data = explode('-', $dtVcto);
    // transforma a data para tempo para calculos e conversões
    $dtTime = mktime(0, 0, 0, $data[1], $data[2], $data[0]);

    // verifica qual o dia da semana a data caiu
    // caso seja domingo adiciona 1 dia para cair na segunda
    // caso seja sábado subtrai 1 dia para cair na sexta
    $diaSem = date('w', $dtTime);
    switch ($diaSem) {
            // domingo
        case 0:
            $difData = intval($data[2]) + 1;
            break;
            // sábado
        case 6:
            $difData = intval($data[2]) + 2;
            break;
            // mantém mesma data
        default:
            $difData = $data[2];
            break;
    }
    // calcula nova data
    $nwTime = mktime(0, 0, 0, $data[1], $difData, $data[0]);
    $novaData = date('Y-m-d', $nwTime);

    return $novaData;
}


function timerAvaliacao(int $minute)
{
    $js = "<script type='text/javascript'>

                var t = " . $minute . ";
                window.onload = function() {
                var fiveMinutes = 60 * t
                , display = document.querySelector('#time');
                startTimer(fiveMinutes, display);
                }

                $(document).mouseleave(function () {
                    alert('Atenção! ao sair da tela desta avaliação, você corre o risco de encerrar a mesma automaticamente');
                });
            </script>";
    return $js;
}

function checkStorage($url)
{
    $file_headers = @get_headers($url);
    if ($file_headers[0] == 'HTTP/1.1 404 Not Found')
        return  false;
    else
        return true;
}

/**
 * Função que verifica se um arquivo existe, baseado na url
 *
 */
function checkfile($url)
{
    if(@file_get_contents($url) !== false){
        return true;
    }
    return false;
}
