<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\Curso;
use App\Models\Turma;
use App\Models\Alunos_matricula;
use App\Models\AlunosMatriculasDisciplinas;
use App\Models\AlunosMatriculasNota;
use App\Models\TurmasDisciplinasAula;
use App\Models\AlunosMatriculasFrequencias;
use App\Models\AlunosLog;
use App\Models\DisciplinasEad;
use App\Models\Disciplinas;
use App\Models\Alunos_fatura;

class BoletimController extends Controller
{
    private $curso, $matricula, $nota, $disciplina, $aula, $frequencias, $discEAD, $disc;

    public function __construct(Curso $crs,
                                Turma $trm,
                                Alunos_matricula $mat,
                                AlunosMatriculasNota $nta,
                                AlunosMatriculasDisciplinas $disc,
                                TurmasDisciplinasAula $aul,
                                AlunosMatriculasFrequencias $freq,
                                DisciplinasEad $dscEad,
                                Disciplinas $dsc,
                                Alunos_fatura $fat) {
        $this->curso = $crs;
        $this->turma = $trm;
        $this->matricula = $mat;
        $this->nota = $nta;
        $this->disciplina = $disc;
        $this->aula = $aul;
        $this->frequencias = $freq;
        $this->disc = $dsc;
        $this->discEAD = $dscEad;
        $this->faturas = $fat;
    }

    /**
     * Index via login CPF
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home.moodle')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $disciplinas = $this->nota->getNotaMatricula($idMatricula);
        $listaDisciplinas = [];

        if(count($disciplinas) > 0){
            foreach($disciplinas as $ln){

                $notasAV = $this->nota->where('matriculas_disciplinas', $ln->idDisc)->get();

                $lnNotas = [];
                $totalNota = 0;

                if(count($notasAV) > 0){
                    foreach($notasAV as $ntav){

                        if($ntav->valorNota != "" && $ntav->valorNota != NULL){
                            //$nta = number_format($ntav->valorNota, 2, ',', '.');
                            $nta = $ntav->valorNota;
                            $totalNota += $ntav->valorNota;
                        }else{
                            $nta = "";
                        }

                        $lnNota = [
                            'idNota' => $ntav->id,
                            'tipoAV' => $ntav->descAvaliacao,
                            'valorNota' => $nta
                        ];

                        array_push($lnNotas, $lnNota);
                    }
                }else{
                    $lnNota = [
                        'idNota' => '',
                        'tipoAV' => ' - ',
                        'valorNota' => ' - '
                    ];
                    array_push($lnNotas, $lnNota);
                }

                /**
                 * Sistema verifica se a soma das notas supera o valor máximo de 10 pontos, caso supere
                 * é calculado a média com base no total de notas validas
                 */
                if ($totalNota > 10) {
                    $totalNota = $totalNota / count($lnNotas);
                }
                
                
                // monta linha da matriz
                $lnDisciplina = [
                    'idDisc' => $ln->idDisc,
                    'nomeDisciplina' => $ln->nomeDisciplina,
                    'avaliacao' => $lnNotas,
                    'totalNota' => $totalNota
                ];


                array_push($listaDisciplinas, $lnDisciplina);
            }
        }

        //dd($listaDisciplinas);

        return view('boletim.notasPresencial', compact('listaDisciplinas'));
    }

    /**
     * Monta boletim academico do Aluno
     *
     * @param Request $request
     * @return void
     */
    public function boletimMoodle(Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }


        $idMatricula = $request->session()->get('matricula')['idMatricula'];

        $matricula = $this->matricula->find($idMatricula);
        $turma = $this->turma->find($matricula->turmas_id);
        $curso = $this->curso->find($turma->cursos_id);
        $aluno = $request->session()->get('aluno');

        // lista disciplinas associadas ao curso do aluno
        $listaDisciplinas = $this->curso->getDisciplinasCurso($idMatricula);

        $disciplinas = [];
        // lista disciplinas relacionadas a matrícula com registros
        $discMatriculas = $this->nota->getNotaMatricula($idMatricula);

        /**
         * Verifica período da matrícula para listagem das disciplinas
         * antes de 20172 - puxa com base no calendário GENNERA
         * de 20181 puxa com base na associação cursos x disciplinas
         */
        if($matricula->codAno >= 20181){
            $listaDisciplinas = $this->curso->getDisciplinasCurso($idMatricula);
        }else{
            $listaDisciplinas = $this->nota->getNotaMatricula($matricula->id);
        }

        if(count($listaDisciplinas) > 0){
            $lnDisc = [];
            foreach($listaDisciplinas as $disc){

                /**
                 * VERIFICA REGISTRO DE NOTAS
                 */
                $notas = $this->nota->getNotaDisciplinaAluno($idMatricula, $disc->disciplina_id);
                $AVO = '---';
                $AVP = '---';
                $AVS = '---';
                $faltas = '---';
                $media = '---';
                if(count($notas) > 0){
                    foreach($notas as $nt){

                        // registra nota avo
                        if($nt->disciplinas_id == $disc->disciplina_id && $nt->valorNota >= 0 && $nt->descAvaliacao === 'AVO'){
                            $AVO = number_format($nt->valorNota, 1, ',', '.');
                        }
                        // registra nota avp
                        if($nt->disciplinas_id == $disc->disciplina_id && $nt->valorNota >= 0 && $nt->descAvaliacao === 'AVP'){
                            $AVP = number_format($nt->valorNota, 1, ',', '.');
                        }
                        // registra nota avs
                        if($nt->disciplinas_id == $disc->disciplina_id && $nt->valorNota >= 0 && $nt->descAvaliacao === 'AVS'){
                            $AVS = number_format($nt->valorNota, 1, ',','.');
                            $media = $AVO+$AVS;
                        }
                    }
                }
                /**
                 * VERIFICA REGISTRO DE FREQUENCIA PARA ATUALIZAÇÃO
                 */
                // int $aula, int $matricula, int $disciplina
                $ttAulas = $this->frequencias->getFrequenciaDisciplina($idMatricula, $disc->disciplina_id, $matricula->codAno);
                $ttFaltas = $this->frequencias->getFrequenciaDisciplinaSts($idMatricula, $disc->disciplina_id, 2);
                // calcula % de faltas
                $totalAulas = count($ttAulas);
                $totalFaltas = count($ttFaltas);
                if($totalAulas > 0 && $totalFaltas >= 0){
                    $faltas = ($totalFaltas * 100) / $totalAulas;
                }

                /**
                 * MONTA ARRAY COM DADOS
                 */
                $lnDisc = [
                    'idDisciplina' => $disc->disciplina_id,
                    'nomeDisciplina' => $disc->nomeDisciplina,
                    'CH' => $disc->cargaHoraria,
                    'faltas' => $totalFaltas,
                    'AVO' => $AVO,
                    'AVP' => $AVP,
                    'AVS' => $AVS,
                    'media' => $media
                ];

                array_push($disciplinas, $lnDisc);
            }
        }

        return view('boletim.boletim', compact('aluno','matricula', 'turma', 'curso','disciplinas'));

    }

/***************************************************************************
 * NOTAS E BOLETIM ALUNOS EAD
 **************************************************************************/
    public function indexEaD(Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        /**
         * Registra Log de acesso
         */
        AlunosLog::create([
            'sistema_id' => 3,
            'alunos_matriculas_id' => $idMatricula,
            'modulo' => 2,
            'acao' => 3,
            'descAcao' => 'Acessou a tela de Notas.',
            'ipAcesso' => $request->ip(),
            'agente' => $request->header('user-agent')
        ]);

        
       // dd($disciplinasEAD);

       // verifica modalidade de curso para montar e validar os registros
       switch ($request->session()->get('matricula')['modalidade']) {
        // registros de frequência presencial
        case 2:
            $disciplinasEAD = $this->discEAD->getDisciplinasEADCurso($request->session()->get('matricula')['idCurso']);
        break;

        case 3:
            $disciplinasEAD = $this->discEAD->getDisciplinaTurma($request->session()->get('matricula')['idTurma']);
        break;

       }

        $listaDisciplinas = [];
        if($disciplinasEAD->count() > 0){
            foreach($disciplinasEAD as $ead){
                $disciplina = $this->disc->find($ead->disciplina_id);

                // verifica se ja existe associação da disciplina ao registro de notas
                $discMatricula = $this->disciplina->where('alunos_matriculas_id', $idMatricula)->where('disciplinas_id', $ead->disciplina_id)->first();
                if(!$discMatricula){
                    $this->disciplina->create([
                        'alunos_matriculas_id' => $idMatricula,
                        'disciplinas_id' => $disciplina->id
                    ]);

                    $discMatricula = $this->disciplina->where('alunos_matriculas_id', $idMatricula)->where('disciplinas_id', $ead->disciplina_id)->first();
                }

                // verifica registro de nota
                $discNota = $this->nota->where('matriculas_disciplinas', $discMatricula->id)->first();
                if(!$discNota){
                    $this->nota->create([
                        'matriculas_disciplinas' => $discMatricula->id
                    ]);
                    $discNota = $this->nota->where('matriculas_disciplinas', $discMatricula->id)->first();
                }

                // monta array de disciplinas
                $lnDisciplina = [
                    'nomeDisciplina' => $disciplina->nomeDisciplina,
                    'totalNota' => $discNota->valorNota,
                    'creditoNota' =>  $discNota->tipoRegistro
                ];

                array_push($listaDisciplinas, $lnDisciplina);
            }
        }
        
        // configuração de inadimplencia
        $mensagemInadimplente = null;
        if($request->session()->get('matricula')['inadimplente'] == 1){
            $mensagemInadimplente = 'Prezado aluno, <a href="'.route('boleto.negociacao').'" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }

        return view('boletim.notasEAD', compact('listaDisciplinas', 'mensagemInadimplente'));
    }

}
