<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Aluno;
use App\Models\Alunos_fatura;
use App\Models\Alunos_matricula;
use App\Models\Boletos_config;
use App\Models\BoletosPagos;
use App\Models\Empresa;
use App\Models\Turma;
use App\Models\Curso;
use App\Models\AlunosNegociacao;
use App\Models\AlunosNegociacaoFaturas;
use App\User;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;

class BoletoController extends Controller
{
    private $matricula, $fatura, $negociacao, $negFaturas, $regBoleto, $turma, $curso;

    public function __construct(Alunos_matricula $mat,
                                Alunos_fatura $fat,
                                AlunosNegociacao $neg,
                                AlunosNegociacaoFaturas $nFat,
                                BoletosPagos $pgo,
                                Turma $trm,
                                Curso $crs)
    {
        $this->matricula = $mat;
        $this->fatura = $fat;
        $this->negociacao = $neg;
        $this->negFaturas = $nFat;
        $this->regBoleto = $pgo;
        $this->turma = $trm;
        $this->curso = $crs;
    }


    /*******************************************************************************
    * BOLETOS
    ******************************************************************************/
    public function index(Alunos_fatura $fat, Request $request)
    {
        //dd($request->session()->get('matricula'));
        // verifica se sessão ainda esta ativa
        if(!isset(auth()->user()->statusAluno)){
            $response['message'] = 'Sessão encerrada por inatividade.';
            Auth::logout();
            return redirect()
                    ->route('form.loginCPF')
                    ->with('error', $response['message']);
        }
        // verifica se a matricula foi cancelada
        if(auth()->user()->statusAluno == 0){
            $response['message'] = 'Sua matrícula foi cancelada, você não pode acessar o sistema.';
            Auth::logout();
            return redirect()
                    ->route('form.loginCPF')
                    ->with('error', $response['message']);
        }

        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $lista = $fat->getFaturasAlunoMatricula(auth()->user()->id, $idMatricula);
        return view('financeiro.boletos', compact('lista'));

    }

    // emissão de boleto
    public function getBoleto(Request $request, Aluno $aln, Alunos_fatura $fat, Alunos_matricula $mat, Empresa $emp, Turma $trm, Boletos_config $config){
        $fatura = $fat->find($request->id);
        $matricula = $mat->find($fatura->alunos_matriculas_id);
        $empresa = $emp->find($matricula->empresas_id);
        $aluno = $aln->find($matricula->alunos_id);
        $turma = $trm->find($matricula->turmas_id);
        $boleto = $config->getConfigBoletoEmpresa($matricula->empresas_id);
        if(count($boleto) == 0){
            return redirect()->back()->with('error', 'Não há configurações de Boletos cadastradas!');
        }

        $dataVcto = new Carbon(date($fatura->dataVcto, strtotime('+0 days')));

        // verifica data de vcto com data atual de emissão para desconto pontualidade
        if($fatura->dataVcto >= date('Y-m-d')){
            $valorFatura = $fatura->valorFatura-$fatura->valorDesconto2;
            $descDesconto = 'Conceder desconto de R$: '.number_format($fatura->valorDesconto, 2, ',','.').' referente: '.$empresa->razaoSocial.' - Aluno - até o vencimento';
        }else{
            $valorFatura = $fatura->valorFatura-$fatura->valorDesconto2;
            $descDesconto = '';
        }

        // dados do beneficiário
        $beneficiario = new \Eduardokum\LaravelBoleto\Pessoa([
            'documento' => $empresa->cnpjEmpresa,
            'nome'      => $empresa->razaoSocial,
            'cep'       => $empresa->cepEmpresa,
            'endereco'  => $empresa->enderecoEmpresa,
            'bairro'    => $empresa->bairroEmpresa,
            'uf'        => $empresa->ufEmpresa,
            'cidade'    => $empresa->cidadeEmpresa,
        ]);

        // dados do pagador
        $pagador = new \Eduardokum\LaravelBoleto\Pessoa([
            'documento' => $aluno->cpfAluno,
            'nome'      => $aluno->nomeAluno,
            'cep'       => $aluno->cepAluno,
            'endereco'  => $aluno->enderecoAluno,
            'bairro'    => $aluno->bairroAluno,
            'uf'        => $aluno->ufAluno,
            'cidade'    => $aluno->cidadeAluno,
        ]);

        // dados do boleto
        /*
        $santander = new \Eduardokum\LaravelBoleto\Boleto\Banco\Santander;
        $santander->setLogo('./imagens/line.png')
                  ->setDataVencimento('2018-10-07 18:14:14')
                  ->setValor($fatura->valorFatura)
                  ->setNumero($fatura->parcelaCorrente)
                  ->setNumeroDocumento($fatura->codFatura)
                  ->setPagador($pagador)
                  ->setBeneficiario($beneficiario)
                  ->setCarteira($boleto[0]->carteiraBanco)
                  ->setCodigoCliente($boleto[0]->codCliente)
                  ->setDescricaoDemonstrativo([$turma->siglaTurma.' '.$turma->nomeCurso.' '.$turma->nomeTurma])
                  ->setInstrucoes([$boleto[0]->instrucoesGerais]);

        $santander->addDescricaoDemonstrativo('Fatura num.: '.$fatura->codFatura.' - Referente a Matrícula num.: '.$matricula->codMatricula);
        //$santander->addInstrucao('Instrução 2');
        */
        $santander = new \Eduardokum\LaravelBoleto\Boleto\Banco\Santander([
            //'logo' => './imagens/line.png',
            'agencia' => $boleto[0]->agenciaBanco,
            'conta' => $boleto[0]->contaBanco,
            'dataVencimento' => $dataVcto,
            'dataDesconto' => $dataVcto,
            'valor' => $valorFatura,
            'desconto' => $fatura->valorDesconto2,
            'numero' => $boleto[0]->contaBanco,
            'numeroDocumento' => $fatura->codFatura,
            'numeroControle' => $fatura->codFatura,
            'pagador' => $pagador,
            'especieDoc' => 'DS',
            'beneficiario' => $beneficiario,
            'carteira' => $boleto[0]->carteiraBanco,
            'codigoCliente' => $boleto[0]->codCliente,
            'descricaoDemonstrativo' => [$turma->siglaTurma.' '.$turma->nomeCurso.' '.$turma->nomeTurma, $boleto[0]->instrucoesGerais, $descDesconto],
            'instrucoes' => [$turma->siglaTurma.' '.$turma->nomeCurso.' '.$turma->nomeTurma, $boleto[0]->instrucoesGerais, $descDesconto],
        ]);
        $santander->getJurosApos(10);
        // renderiza boleto
        return $santander->renderHTML($print = true, $instrucoes = true);
    }

    // lista boletos para o moodle
    public function getBoletoMoodle(Request $request, Alunos_fatura $fat){
        $idAluno = base64_decode(base64_decode(base64_decode($request->id)));
        $idMatricula = $request->session()->get('matricula')['idMatricula'];

        $lista = $fat->getFaturasAlunoMatricula($idAluno, $idMatricula);
        return view('aluno.boletosMoodle', compact('lista'));
    }

    public function declaracaoIR(Request $request)
    {
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $anoBase = 2018;
        $matricula = $this->matricula->getMatriculaIDAluno($idMatricula)->first();
        $faturas = $this->fatura->getFaturasPagasMatricula($idMatricula, $anoBase);
        $valorPago = 0;
        if(count($faturas) > 0){
            foreach ($faturas as $fat){
                $valorPago += $fat->valorRecebido;
            }
        }
        $mes = ['01' => 'Janeiro', '02' => 'Fevereiro', '03' => 'Março', '04' => 'Abril', '05' => 'Maio', '06' => 'Junho', '07' => 'Julho', '08' => 'Agosto', '09' => 'Setembro', '10' => 'Outubro', '11' => 'Novembro', '12' => 'Dezembro'];

        $dataEmissao = date('d').' de '.$mes[date('m')].' de '.date('Y');

        return view('financeiro.declaracaoIR', compact('matricula', 'valorPago', 'anoBase', 'dataEmissao'));
    }

    /**
     * Lista boletos vencidos para negociação
     *
     * @return void
     */
    public function negociacao(Request $request)
    {
        // verifica se o aluno esta apto a realizar negociação
        if ($request->session()->get('matricula')['inadimplente'] == 0) {
            return redirect()
                    ->route('moodle.financeiro')
                    ->with('error', 'Você já possui uma proposta de negociação em andamento.');
        }

        //dd($request->session()->get('matricula')['idMatricula']);
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home.moodle')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $matricula = $this->matricula->find($idMatricula);
        if($matricula->bolsas_id == 276){
            return redirect()
                ->route('home.moodle')
                ->with('warning', 'Infelizmente as negociações não estão disponíveis neste momento!');
        }

        $lista = $this->fatura->getFaturasAtrasadasMatricula($idMatricula);

        // verifica se há faturas a serem negociadas
         if($lista->count() == 0){
            return redirect()
                    ->route('moodle.financeiro')
                    ->with('error', 'Não há mensalidades disponíveis para negociação!');
         }

        $boletos = [];
        $totalDivida = 0;
        // calcula boletos vencidos
        if($lista->count() > 0){
            foreach ($lista as $fat) {

                // calcula qtde de dias de atraso
                $dataVencimento = Carbon::createFromFormat('Y-m-d', $fat->dataVcto);
                $dataAtual = Carbon::createFromFormat('Y-m-d', date('Y-m-d'));
                $qtdeDiasAtraso = $dataAtual->diffInDays($dataVencimento);

                $valorBoleto = number_format(($fat->valorFatura - $fat->valorDesconto - $fat->valorDesconto2),2);

                // total multa
                $valorMulta = number_format(($valorBoleto * 0.02), 2);
                // total Juros
                $valorJuros = number_format(((($valorBoleto * 0.01) / 30) * $qtdeDiasAtraso), 2);

                $totalBoleto = $valorBoleto+$valorJuros+$valorMulta;

                $lnFatura = [
                    'idFatura' => $fat->id,
                    'codigo' => $fat->codFatura,
                    'diasAtraso' => $qtdeDiasAtraso,
                    'dataVcto' => date('d/m/Y', strtotime($fat->dataVcto)),
                    'valorBoleto' => number_format($valorBoleto, 2,',' ,'.'),
                    'juros' => number_format($valorJuros,2,',','.'),
                    'multa' => number_format($valorMulta,2,',','.'),
                    'parcela' => $fat->parcelaCorrente,
                    'statusFatura' => $fat->statusFatura,
                    'totalBoleto' => number_format($totalBoleto,2,',','.')
                ];

                array_push($boletos, $lnFatura);

                // total da divida
                $totalDivida += $totalBoleto;
            }
        }

        /**
         * Monta planos de negociação
         * 1ª Opção - Pagar toda sua dívida na data do próximo vencimento de mensalidade
         * 2ª Opção - Dividir a dívida em um prazo de 50% em 30 dias e os demais 50% em 45 dias da data da negociação.
         */
        $negociacao = [];

        // resgata data da próxima fatura
        $dataFatura = $this->fatura->where('alunos_matriculas_id', $idMatricula)->where('dataVcto', '>', date('Y-m-d'))->orderBy('dataVcto', 'asc')->first();

        //Vwrifica se a Matricula esta habilitada a negociar
        if($matricula->isHabilitadoNegociar()){
            //Caso a matricula estive com condição 1, com faturas atrasas e no maximo 1 negociação pendente
            if($matricula->negociacaoCondicao() == 1){

                $plano1 = [
                    'idplano' => 1,
                    'plano' => [
                        [
                            'ordem' => 1,
                            'valorParcela' => $totalDivida,
                            'vencimento' => $this->validaVcto(date('Y-m-d', strtotime('+30 days', strtotime(date('Y-m-d')))))
                        ]
                    ],
                    'descricao' => 'Plano de pagamento 1',
                ];
                array_push($negociacao, $plano1);

                $plano2 = [
                    'idplano' => 2,
                    'plano' => [
                        [
                            'ordem' => 1,
                            'valorParcela' => ($totalDivida / 2),
                            'vencimento' => $this->validaVcto(date('Y-m-d', strtotime('+30 days', strtotime(date('Y-m-d')))))
                        ],
                        [
                            'ordem' => 2,
                            'valorParcela' => ($totalDivida / 2),
                            'vencimento' => $this->validaVcto(date('Y-m-d', strtotime('+60 days', strtotime(date('Y-m-d')))))
                        ]
                    ],
                    'descricao' => 'Plano de pagamento 2',
                ];
                array_push($negociacao, $plano2);

            }
            // Caso o aluno entre na excessão de negociação
            //Com mais de 2 negociações anteriores a data
            else{
                $plano1 = [
                    'idplano' => 1,
                    'plano' => [
                        [
                            'ordem' => 1,
                            'valorParcela' => $totalDivida,
                            'vencimento' => $this->validaVcto(date('Y-m-d', strtotime('+30 days', strtotime(date('Y-m-d')))))
                        ]
                    ],
                    'descricao' => 'Plano de pagamento 1',
                ];
                array_push($negociacao, $plano1);

                $plano2 = [
                    'idplano' => 2,
                    'plano' => [
                        [
                            'ordem' => 1,
                            'valorParcela' => ($totalDivida*0.30),
                            'vencimento' => $this->validaVcto(date('Y-m-d', strtotime('+72 hours', strtotime(date('Y-m-d')))))
                        ],
                        [
                            'ordem' => 2,
                            'valorParcela' => ($totalDivida*0.2333),
                            'vencimento' => $this->validaVcto(date('Y-m-d', strtotime('+30 days', strtotime(date('Y-m-d')))))
                        ],
                        [
                            'ordem' => 3,
                            'valorParcela' => ($totalDivida*0.2333),
                            'vencimento' => $this->validaVcto(date('Y-m-d', strtotime('+60 days', strtotime(date('Y-m-d')))))
                        ],
                        [
                            'ordem' => 4,
                            'valorParcela' => ($totalDivida*0.2333),
                            'vencimento' => $this->validaVcto(date('Y-m-d', strtotime('+90 days', strtotime(date('Y-m-d')))))
                        ]
                    ],
                    'descricao' => 'Plano de pagamento 2',
                ];
                array_push($negociacao, $plano2);
            }

        }

        // configuração de inadimplencia
        $mensagemInadimplente = null;
        if($request->session()->get('matricula')['inadimplente'] == 1){
            $mensagemInadimplente = 'Prezado(a) aluno(a), escolha um dos planos de pagamento apresentado para negociar seus débitos e continuar usufruindo dos benefícios de sua Pós-Graduação.';
        }

        return view('financeiro.boletos', compact('lista', 'mensagemInadimplente', 'boletos', 'totalDivida', 'negociacao', 'matricula'));
    }

    /**
     * Registra Negociação do Aluno EaD
     *
     * @param Request $request
     * @return void
     */
    public function boletosNegociados(Request $request)
    {
        // verifica se o aluno esta apto a realizar negociação
        if ($request->session()->get('matricula')['inadimplente'] == 0) {
            return redirect()
                    ->route('moodle.financeiro')
                    ->with('error', 'Você já possui uma proposta de negociação em andamento.');
        }

        // inicio
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home.moodle')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $matricula = $this->matricula->find($idMatricula);
        // valida matricula
        if(!$matricula){
            return redirect()
                    ->back()
                    ->with('error', 'Matrícula não localizada, por favor atualize sua página e tente novamente.');
        }


        /**
         * Valida Faturas em aberto
         */
        $lista = $this->fatura->getFaturasAtrasadasMatricula($idMatricula);

        if($lista->count() == 0){
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Faturas não localizadas!');
        }

        $boletos = [];
        $totalDivida = 0;
        // calcula boletos vencidos
        if($lista->count() > 0){
            foreach ($lista as $fat) {

                // calcula qtde de dias de atraso
                $dataVencimento = Carbon::createFromFormat('Y-m-d', $fat->dataVcto);
                $dataAtual = Carbon::createFromFormat('Y-m-d', date('Y-m-d'));
                $qtdeDiasAtraso = $dataAtual->diffInDays($dataVencimento);

                $valorBoleto = number_format(($fat->valorFatura - $fat->valorDesconto - $fat->valorDesconto2),2);

                // total multa
                $valorMulta = number_format(($valorBoleto * 0.02), 2);
                // total Juros
                $valorJuros = number_format(((($valorBoleto * 0.01) / 30) * $qtdeDiasAtraso), 2);

                $totalBoleto = $valorBoleto+$valorJuros+$valorMulta;

                // total da divida
                $totalDivida += $totalBoleto;

                // armazena id da fatura
                $idFatura[] = $fat->id;
            }
        }

        // dados negociação
        $qtdeParcelas = count($request->valorParcela);

        /**
         * Registra dados da negociação
         */
        $proxIDNeg = $this->negociacao->orderBy('id', 'desc')->get();
        if(count($proxIDNeg) == 0){
            $idNeg = 1;
        }else{
            $idNeg = $proxIDNeg[0]->id + 1;
        }

        $codigoNegociacao = date('ym').str_pad($idNeg, 5, 0, STR_PAD_LEFT);
        $dadosNegociacao = [
            'alunos_matriculas_id' => $matricula->id,
            'codigoNegociacao' => $codigoNegociacao,
            'totalDebito' => $totalDivida,
            'totalDesconto' => 0,
            'concessaoDesconto' => 2,
            'valorEntrada' => 0,
            'qtdeParcelas' => $qtdeParcelas,
            'users_id' => 693
        ];

        $addNeg = $this->negociacao->create($dadosNegociacao);


        if($addNeg){
            /**
             * Após inserção da negociação registra as faturas que estão sendo negociadas,
             * Atualizando o status das mesmas como NEGOCIADAS
             * E atualizando também o status de inadimplente do aluno para Adimplente
             **/
            if(count($idFatura) > 0){
                foreach($idFatura as $fatNeg){

                    // registra valores de multas e juros
                    $qtdeDiasAtraso = 0;
                    $fatura = $this->fatura->find($fatNeg);

                    // calcula qtde de dias de atraso
                    $dataVencimento = Carbon::createFromFormat('Y-m-d', $fatura->dataVcto);
                    $dataAtual = Carbon::createFromFormat('Y-m-d', date('Y-m-d'));
                    $qtdeDiasAtraso = $dataAtual->diffInDays($dataVencimento);

                    // total a pagar
                    $valorBoleto = number_format(($fatura->valorFatura - $fatura->valorDesconto - $fatura->valorDesconto2),2);
                    // total multa
                    $valorMulta = number_format(($valorBoleto * 0.02), 2);
                    // total Juros
                    $valorJuros = number_format(((($valorBoleto * 0.01) / 30) * $qtdeDiasAtraso), 2);
                    $totalBoleto = $valorBoleto+$valorJuros+$valorMulta;

                    $lnFatura = [
                        'alunos_faturas_id' => $fatura->id,
                        'numDocumento' => $fatura->codFatura,
                        'valorDocumento' => $valorBoleto,
                        'dataVctoDocumento' => $fatura->dataVcto,
                        'dataOcorrencia' => date('Y-m-d H:i:s'),
                        'valorMora' => $valorJuros,
                        'valorMulta' => $valorMulta,
                        'ocorrenciaDescricao' => 'Parcela negociada via Sistema SAV, neg. nº '.$codigoNegociacao,
                        'obsPagto' => 'Fatura negociada em '.date('d/m/y').', com '.$qtdeDiasAtraso.' dias de atraso. Negociação n. '.$codigoNegociacao,
                        'statusBoleto' => 3
                    ];
                    $this->regBoleto->create($lnFatura);

                    // registra as faturas na tabela da negociação
                    $lnFatNeg = [
                        'alunos_faturas_id' => $fatNeg,
                        'alunos_negociacao_id' => $addNeg->id,
                        'tipoRegistro' => 1 // fatura negociada
                    ];
                    $this->negFaturas->create($lnFatNeg);

                    // atualiza fatura com o status de negociada
                    //$faturaNegociada = $this->fatura->find($fatNeg);
                    $fatura->update(['statusFatura' => 3]);
                }
            }

            /**
             * Após o registro das faturas a serem negociadas
             * É gerada as respectivas faturas a serem pagas.
             */
            if($qtdeParcelas > 0){
                foreach($request->dataVcto as $k_vcto => $vcto){
                    foreach($request->valorParcela as $k_valor => $valor){
                        if($k_vcto == $k_valor){

                            // monta código da fatura
                            // pega informações das faturas relacionadas a matrícula passada
                            $faturas = $this->fatura->getFaturasMatricula($matricula->id)->first();
                            $qtdeParc = $faturas->qtdeParcela; // qtde de parcelas que a matricula possui
                            $nova_qtdeParc = $qtdeParc + 1; // adiciona nova parcela
                            $codFatura = $matricula->codMatricula.".".str_pad($nova_qtdeParc, 3, 0, STR_PAD_LEFT); // novo cod. da fatura

                            $dados_fatura = [
                                'alunos_matriculas_id' => $matricula->id,
                                'codFatura' => $codFatura,
                                'dataVcto' => $vcto,
                                'valorFatura' => $valor,
                                'valorDesconto' => '0.00',
                                'valorDesconto2' => '0.00',
                                'qtdeParcela' => $nova_qtdeParc,
                                'parcelaCorrente' => $nova_qtdeParc,
                                'tipoPagto' => '2',
                                'statusFatura' => '0',
                                'observacoes' => 'Parcela referente a negociação nr.: '.$codigoNegociacao,
                                'emAtraso' => '0',
                                'registradaBco' => '0',
                                'tipoFatura' => '1'
                            ];
                            // cadastra fatura
                            $response = $this->fatura->create($dados_fatura);

                            $lnFatNeg = [
                                'alunos_faturas_id' => $response->id,
                                'alunos_negociacao_id' => $addNeg->id,
                                'tipoRegistro' => 2 // boletos novos
                            ];
                            $this->negFaturas->create($lnFatNeg);

                            // atualiza qtde de parcelas das demais faturas
                            $this->fatura->where('alunos_matriculas_id', $matricula->id)->update(['qtdeParcela' => $nova_qtdeParc]);
                        }
                    }

                }
            }
        }

        if($response){
            // atualiza status do aluno para adimpente
            $this->matricula->where('id', $matricula->id)->update(['inadimplente' => '0']);

            // resgata dados da matrícula, curso, turma, etc...
            $turma = $this->turma->find($matricula->turmas_id);
            $curso = $this->curso->find($turma->cursos_id);

            // verifica qual id da empresa para atribuir dados pagseguro
            if (in_array($matricula->empresas_id, [6,13])) {
                $emailPagseguro = env('PAGSEGURO_IC_EMAIL');
                $tokenPagseguro = env('PAGSEGURO_IC_TOKEN');
            } else {
                $emailPagseguro = env('PAGSEGURO_EMAIL');
                $tokenPagseguro = env('PAGSEGURO_TOKEN');
            }

            // cria sessão com as informações da matrícula selecionada
            $request->session()->put('matricula', [
                'idMatricula' => $matricula->id,
                'codMatricula' => $matricula->codMatricula,
                'idCurso' => $curso->id,
                'siglaCurso' => $curso->siglaCurso,
                'nomeCurso' => $curso->nomeCurso,
                'idTurma' => $turma->id,
                'nomeTurma' => $turma->nomeTurma,
                'modalidade' => $matricula->modalidade,
                'inadimplente' => 0,
                'linkava' => $matricula->linkAva(),
                'tipoCurso' => $curso->tipoCurso,
                'bolsa' => $matricula->bolsas_id,
                'bloqueioSAV' => true,
                'idEmpresa' => $matricula->empresas_id,
                'pagseguro_email' => $emailPagseguro,
                'pagseguro_token' => $tokenPagseguro
            ]);

            return redirect()
                    ->route('negociacao.show', [$addNeg->id])
                    ->with('success', 'Negociação cadastrada com sucesso!');
        }else{
            return redirect()
                    ->back()
                    ->with('error', 'Erro ao registrar negociação, por favor tente novamente!');
        }

        // fim
    }

    /**
     * Lista dados da negociação para geração de contrato de confissão de dívida.
     *
     * @param integer $idNegociacao
     * @return void
     */
    public function negociacaoShow(int $idNegociacao, Request $request)
    {

        $negociacao = $this->negociacao->find($idNegociacao);
        $matricula = $this->matricula->getAlunoDadosMatriculaID($negociacao->alunos_matriculas_id);

        $faturasNegociacao = $this->negFaturas->getFaturasNegociacao($idNegociacao, 2);
        $listaNegociadas = $this->negFaturas->getFaturasNegociacao($idNegociacao, 1);
        $faturasNegociadas = [];

        if($listaNegociadas->count() > 0){
            foreach($listaNegociadas as $fat){

                $valorNegociado = $this->regBoleto->where('alunos_faturas_id', $fat->id)->where('statusBoleto', '3')->orderBy('id', 'desc')->first();

                if($fat->statusFatura == 0){
                    $statusFatura = '<span class="label label-default">Em aberto</span>';
                }
                if($fat->statusFatura == 1){
                    $statusFatura = '<span class="label label-danger">Atrasada</span>';
                }
                if($fat->statusFatura == 2){
                    $statusFatura = '<span class="label label-success">Paga</span>';
                }
                if($fat->statusFatura == 3){
                    $statusFatura = '<span class="label label-warning">Negociada</span>';
                }
                if($fat->statusFatura == 4){
                    $statusFatura = '<span class="label label-info">Isento</span>';
                }
                if($fat->statusFatura == 5){
                    $statusFatura = '<span class="label bg-navy">Cancelada</span>';
                }
                if($fat->statusFatura == 6){
                    $statusFatura = '<span class="label bg-primary">Crédito Financeiro</span>';
                }
                if($fat->statusFatura == 7){
                    $statusFatura = '<span class="label bg-purple">Crédito Disciplina</span>';
                }

                // verifica se desconto foi concedido
                if($negociacao->concessaoDesconto == 1){
                    $valorDesconto = $fat->valorDesconto;
                }else{
                    $valorDesconto = 0.00;
                }

                $valorFatura = $fat->valorFatura - $fat->valorDesconto - $fat->valorDesconto2;

                $totalFatura = $valorFatura + $valorNegociado->valorMora + $valorNegociado->valorMulta;

                $lnNegociadas = [
                    'id' => $fat->id,
                    'codFatura' => $fat->codFatura,
                    'dataVcto' => date('d/m/Y', strtotime($fat->dataVcto)),
                    'valorFatura' => number_format($valorFatura,2,',','.'),
                    'valorDesconto' => number_format($valorDesconto, 2,',','.'),
                    'valorJuros' => number_format($valorNegociado->valorMora,2,',','.'),
                    'valorMulta' => number_format($valorNegociado->valorMulta,2,',','.'),
                    'totalFatura' => number_format($totalFatura,2,',','.'),
                    'statusFatura' => $statusFatura
                ];

                array_push($faturasNegociadas, $lnNegociadas);
            }
        }
        // configuração de inadimplencia
        $mensagemInadimplente = null;
        if($request->session()->get('matricula')['inadimplente'] == 1){
            $mensagemInadimplente = 'Prezado aluno, <a href="'.route('boleto.negociacao').'" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }


        return view('financeiro.detalheNegociacao', compact('negociacao', 'matricula', 'faturasNegociacao', 'faturasNegociadas', 'mensagemInadimplente'));
    }

    /**
     * Undocumented function
     *
     * @param integer $id
     * @return void
     */
    public function upBoleto($id, Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home.moodle')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        $id = base64_decode(base64_decode(base64_decode($id)));

        $fatura = $this->fatura->find($id);
        if(!$fatura){
            echo "<script> alert('Seu boleto não foi localizado.') </script>";
            return redirect()
                    ->back()
                    ->with('error', 'Boleto não localizado!');
        }

        if($fatura->statusFatura == '3'){
            echo "<script> alert('Seu boleto já esta disponível na sua área do aluno.') </script>";
            return redirect()
                    ->back()
                    ->with('error', 'Boleto não localizado!');
        }

        $matricula = $this->matricula->find($fatura->alunos_matriculas_id);

        $qtdeParcela = $fatura->qtdeParcela+1;
        $valorParcela = $fatura->valorFatura - $fatura->valorDesconto;
        $codFatura = $matricula->codMatricula.".".str_pad($qtdeParcela, 3, 0, STR_PAD_LEFT); // novo cod. da fatura

        if($fatura->parcelaCorrente == 1){
            $dataVcto = date('Y-m-d', strtotime("+30 days", strtotime($fatura->dataVcto)));
        }else{
            $dataVcto = date('Y-m-d', strtotime("+5 days", strtotime($fatura->dataVcto)));
        }
        // atualiza status da fatura
        $fatura->update(['statusFatura' => '3', 'observacoes' => 'Aluno(a) atualizou o boleto via SAV.']);

        $dados_fatura = [
            'alunos_matriculas_id' => $fatura->alunos_matriculas_id,
            'codFatura' => $codFatura,
            'dataVcto' => $dataVcto,
            'valorFatura' => $valorParcela,
            'valorDesconto' => 0,
            'valorDesconto2' => 0,
            'qtdeParcela' => $qtdeParcela,
            'parcelaCorrente' => $qtdeParcela,
            'tipoPagto' => 2,
            'statusFatura' => 0,
            'observacoes' => 'Fatura gerada a partir da negociação da fatura num.: '.$fatura->codFatura,
            'emAtraso' => 1,
            'registradaBco' => 0,
	        'tipoFatura' => 1
        ];

        $response = $this->fatura->create($dados_fatura);

        if($response){

            // atualiza status do aluno
            $matricula->update(['inadimplente' => 0]);

            return redirect()->to('https://sis.estratego.site/boleto_santander/' . base64_encode(base64_encode(base64_encode($response->id))));
        }else{
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Erro ao Atualizar Boleto, entre em contato com seu tutor!');

        }

    }

    /**
     * Undocumented function
     *
     * @param integer $id
     * @return void
     */
    public function upBoleto2($id, Request $request)
    {
        $id = base64_decode(base64_decode(base64_decode($id)));

        $fatura = $this->fatura->find($id);
        if(!$fatura){
            echo "Boleto não localizado! Entre em contato com seu Tutor!";
            exit();
        }

        return redirect()->to('https://sis.estratego.site/boleto_santander/' . base64_encode(base64_encode(base64_encode($fatura->id))));
        /*
        //verifica status do boleto
        if($fatura->statusFatura == 2){
            echo "Seu boleto já foi registrado como pago!";
            exit();
        }
        // boleto ja negociado
        if($fatura->statusFatura == '3'){
            echo "Seu boleto já esta disponível na sua área do aluno.";
            exit();
        }

        $matricula = $this->matricula->find($fatura->alunos_matriculas_id);

        $qtdeParcela = $fatura->qtdeParcela+1;
        $valorParcela = $fatura->valorFatura - $fatura->valorDesconto;
        $codFatura = $matricula->codMatricula.".".str_pad($qtdeParcela, 3, 0, STR_PAD_LEFT); // novo cod. da fatura

        if($fatura->parcelaCorrente == 1){
            $dataVcto = date('Y-m-d', strtotime("+30 days", strtotime($fatura->dataVcto)));
        }else{
            $dataVcto = date('Y-m-d', strtotime("+5 days", strtotime($fatura->dataVcto)));
        }
        // atualiza status da fatura
        $fatura->update(['statusFatura' => '3', 'observacoes' => 'Aluno(a) atualizou o boleto via SAV.']);

        $dados_fatura = [
            'alunos_matriculas_id' => $fatura->alunos_matriculas_id,
            'codFatura' => $codFatura,
            'dataVcto' => $dataVcto,
            'valorFatura' => $valorParcela,
            'valorDesconto' => 0,
            'valorDesconto2' => 0,
            'qtdeParcela' => $qtdeParcela,
            'parcelaCorrente' => $qtdeParcela,
            'tipoPagto' => 2,
            'statusFatura' => 0,
            'observacoes' => 'Fatura gerada a partir da negociação da fatura num.: '.$fatura->codFatura,
            'emAtraso' => 1,
            'registradaBco' => 0,
	        'tipoFatura' => 1
        ];

        $response = $this->fatura->create($dados_fatura);

        if($response){

            // atualiza status do aluno
            $matricula->update(['inadimplente' => 0]);

            return redirect()->to('https://sis.estratego.site/boleto_santander/' . base64_encode(base64_encode(base64_encode($response->id))));
        }else{
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Erro ao Atualizar Boleto, entre em contato com seu tutor!');

        }
        */

    }


    /**
     * Formata moeda para inserção no BD
     *
     * @param [type] $value
     * @return void
     */
    private function formataMoedaSQL($value)
    {
        $busca = ['.', ','];
        $substitui = ['', '.'];

        $valor = str_replace($busca, $substitui, $value);

        return $valor;
    }

    // função que valida as datas de vencimentos das faturas, para que elas não caiam em finais de semana
    // $dtVcto = yyyy-mm-dd
    private function validaVcto($dtVcto)
    {

        // desmembra data
        $data = explode('-', $dtVcto);
        // transforma a data para tempo para calculos e conversões
        $dtTime = mktime(0, 0, 0, $data[1], $data[2], $data[0]);

        // verifica qual o dia da semana a data caiu
        // caso seja domingo adiciona 1 dia para cair na segunda
        // caso seja sábado subtrai 1 dia para cair na sexta
        $diaSem = date('w', $dtTime);
        switch($diaSem){
            // domingo
            case 0 :
                $difData = intval($data[2])+1;
            break;
            // sábado
            case 6 :
                $difData = intval($data[2])+2;
            break;
            // mantém mesma data
            default :
                $difData = $data[2];
            break;
        }
        // calcula nova data
        $nwTime = mktime(0,0,0, $data[1], $difData, $data[0]);
        $novaData = date('d/m/Y', $nwTime);

        return $novaData;
    }

}
