<?php

namespace App\Http\Controllers;

use App\Helpers\Checklinkfile;
use App\Http\Requests\StoreDocs;
use App\Http\Util\Curl;
use Illuminate\Http\Request;

use App\Models\Alunos_matricula;
use App\Models\AlunosMatriculasDocumento;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;

class DocumentoController extends Controller
{
    private $matricula, $documentos, $gClient;

    public function __construct(
        Alunos_matricula $mat,
        AlunosMatriculasDocumento $doc
    ) {
        $this->matricula = $mat;
        $this->documentos = $doc;
    }

    /**
     * Visualização de documentos que foram entregues e que estão faltando
     *
     * @param Request $request
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\Http\RedirectResponse|\Illuminate\View\View
     */
    public function index(Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if (!isset($request->session()->get('matricula')['idMatricula'])) {
            return redirect()
                ->route('home')
                ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $documentos = $this->documentos->where('alunos_matriculas_id', $idMatricula)->orderBy('tipoDocumento', 'asc')->get();

        // configuração de inadimplencia
        $mensagemInadimplente = null;
        if ($request->session()->get('matricula')['inadimplente'] == 1) {
            $mensagemInadimplente = 'Prezado aluno, <a href="' . route('boleto.negociacao') . '" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }

        foreach ($documentos as $key => $documento) {
            $fileLink = new Checklinkfile($documento->nomeArquivo, 1, $idMatricula);
            $documentos[$key]->link = $fileLink->getLink();
        }


        $data['documentos']             = $documentos;
        $data['mensagemInadimplente']   = $mensagemInadimplente;
        return view('documentos.index', $data);
    }

    /**
     * Cadastra Documentos no Servidor
     *
     * @param StoreDocs $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function storeDoc(StoreDocs $request)
    {
        // valida dados
        if (!$request->validated()) {
            return redirect()->withErrors()->back();
        }

        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $pastaDestino = 'docs/alunos/' . base64_encode($idMatricula) . '/';

        // verifica o tipo de documento
        switch ($request->tipoDocumento) {
            case 1:
                $tipoDoc = 'cpf';
                break;
            case 2:
                $tipoDoc = 'rg';
                break;
            case 3:
                $tipoDoc = 'comprovante-residencia';
                break;
            case 4:
                $tipoDoc = 'diploma-graduacao';
                break;
            case 5:
                $tipoDoc = 'contrato';
                break;
            default:
                $tipoDoc = 'nao-identificado';
                break;
        }
        if (!in_array($request->file('upload')->extension(), ['pdf'])) {
            $extensao = mb_strtoupper($request->file('upload')->extension());
            return redirect()
                ->back()
                ->with("warning", "Atenção! O Formato <b>{$extensao}</b> não é aceito pelo sistema.
                           O Formato aceito é somente <b>PDF/A</b>");
        }

        if ($request->hasFile('upload') && $request->file('upload')->isValid()) {
            $curl = new Curl("POST", env('URL_API_PDFA') . "pdfmetadata/", ["file" => curl_file_create($request->file('upload')->getPathname())]);
            $response = $curl->getResponse();

            if (!$response['response'] || @$response['http'] == 404) return redirect()->back()->with("warning", "Aconteceu um erro durante a requisição, tente outra vez!");

            if (!$response['response']  || @$response['http'] == 404) return redirect()->back()->with("warning", "Aconteceu um erro durante a requisição, tente outra vez!");

            $response = json_decode($response['response']);
            $findme = "pdfaid";
            if ($response and !strpos($response->metadata, $findme)) return redirect()->back()->with("warning", "O arquivo PDF não é um tipo de PDF/A válido");

            $date = date("Y-m-d-H-i-s");
            $nomeArquivo = str_slug($idMatricula . "-" . $tipoDoc . "-" . $date, '-'); // define nome
            $extensao = $request->file('upload')->extension(); // pega a extensão do arquivo
            $novoNome = "{$nomeArquivo}.{$extensao}";

            /**************************************************
             * a lógica a seguir trata sa transição de upload de arquivos para a central de documentos
             ***************************************************/

            if (env('C_ACTIVE') == 0) {
                $upload = $request->file('upload')->storeAs($pastaDestino, $novoNome);
            } else {
                //storage in ftp path
                $upload = Storage::disk('ftp')->put($pastaDestino .  $novoNome, fopen($request->file('upload'), 'r+'));
            }

            if ($upload) {

                $dados = [
                    'alunos_matriculas_id'  => $idMatricula,
                    'tipoDocumento'         => $request->tipoDocumento,
                    'nomeArquivo'           => $novoNome,
                    'statusArquivo'         => 0
                ];
                $response                   = $this->documentos->create($dados);
                if ($response) {
                    return redirect()
                        ->back()
                        ->with('success', 'Documento enviado com sucesso! <br /> OBS: Nossa equipe vai analisar suas documentações e informará se as mesmas estão de acordo ou não com os critérios solicitados.');
                } else {
                    return redirect()
                        ->back()
                        ->with('error', 'Ops! Erro ao registrar o Documento, por favor atualize sua página e tente novamente!');
                }
            } else {
                return redirect()
                    ->back()
                    ->with('error', 'Erro ao enviar o arquivo para o servidor, atualize sua página e tente novamente.
                        Caso o erro persista, verifique se o documento esta de acordo com os paramêtros aceitos pelo sistema.');
            }
        } else {
            return redirect()
                ->back()
                ->with('error', 'Erro ao enviar o arquivo para o servidor, atualize sua página e tente novamente.
                        Caso o erro persista, verifique se o documento esta de acordo com os paramêtros aceitos pelo sistema.');
        }
    }

}
