<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\Alunos_fatura;
use App\Models\Alunos_matricula;
use App\Models\AlunosMatriculasDisciplinas;
use App\Models\AlunosMatriculasFrequencias;
use App\Models\AlunosMatriculasNota;
use App\Models\Turma;
use App\Models\Curso;
use App\Models\TurmasDisciplinasAula;
use App\Models\Usuario;
use App\Models\AlunosLog;
use App\Models\DisciplinasEad;
use App\Models\Disciplinas;

class FrequenciaController extends Controller
{
    
    private $matriculas, $disciplinaMat, $frequencias, $notas, $turma, $curso, $aula, $usuario,
            $discEAD, $disc;
    
    public function __construct(                
                Alunos_matricula $mat,
                AlunosMatriculasDisciplinas $dsc, 
                AlunosMatriculasFrequencias $freq,
                AlunosMatriculasNota $nt,
                Turma $trm,
                Curso $crs,
                Alunos_fatura $fat,
                TurmasDisciplinasAula $aul,
                Usuario $user,
                DisciplinasEad $dscEad,
                Disciplinas $disc) {

        $this->matriculas = $mat;
        $this->disciplinaMat = $dsc;
        $this->frequencias = $freq;
        $this->notas = $nt;
        $this->turma = $trm;
        $this->curso = $crs;
        $this->aula = $aul;
        $this->usuario = $user;
        $this->disc = $disc;
        $this->discEAD = $dscEad;
        $this->faturas = $fat;
    }
       
    
    /**
     * Tela inicial de Frequências
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {        
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home.moodle')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        // dd($request->session()->get('matricula'));
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $disciplinas = [];

        // verifica modalidade de curso para montar e validar os registros
        switch ($request->session()->get('matricula')['modalidade']) {
            // registros de frequência presencial
            case 1:
                $lista = $this->notas->getNotaMatriculaFrequencia($idMatricula);
                if(count($lista) > 0){
                    foreach($lista as $ln){
                        
                        $frequencia = $ln->percFrequencia;
                        
                        // monta array
                        $lnAula = [
                            'idDiscMatricula'   => $ln->matriculas_disciplinas,
                            'nomeDisciplina'    => $ln->nomeDisciplina,
                            'percFalta'         => $frequencia,
                            'creditoNota'       =>  $discNota->tipoRegistro
                        ];
                        
                        array_push($disciplinas, $lnAula);
                    }
                }    
            break;

            // registros de frequências EaD
            case 2: 
            $disciplinasEAD = $this->discEAD->getDisciplinasEADCurso($request->session()->get('matricula')['idCurso']);
        
            if($disciplinasEAD->count() > 0){
                foreach($disciplinasEAD as $ead){
                    $disciplina = $this->disc->find($ead->disciplina_id);
    
                    // verifica se ja existe associação da disciplina ao registro de notas
                    $discMatricula = $this->disciplinaMat->where('alunos_matriculas_id', $idMatricula)->where('disciplinas_id', $ead->disciplina_id)->first();
                    if(!$discMatricula){
                        $this->disciplinaMat->create([
                            'alunos_matriculas_id'  => $idMatricula,
                            'disciplinas_id'        => $disciplina->id
                        ]);
    
                        $discMatricula = $this->disciplinaMat->where('alunos_matriculas_id', $idMatricula)->where('disciplinas_id', $ead->disciplina_id)->first();
                    }
    
                    // verifica registro de nota
                    $discNota = $this->notas->where('matriculas_disciplinas', $discMatricula->id)->first();
                    if(!$discNota){
                        $this->notas->create([
                            'matriculas_disciplinas' => $discMatricula->id
                        ]);
                        $discNota = $this->notas->where('matriculas_disciplinas', $discMatricula->id)->first();
                    }
    
                    // monta array de disciplinas
                    $lnDisciplina = [
                        'idDiscMatricula'   => $discMatricula->id,
                        'nomeDisciplina'    => $disciplina->nomeDisciplina,
                        'percFalta'         => $discNota->percFrequencia,
                        'creditoNota'       =>  $discNota->tipoRegistro
                    ];
    
                    array_push($disciplinas, $lnDisciplina);
                }
            } 
            break;

            case 3:  
                //$disciplinasEAD = $this->discEAD->getDisciplinasEADCurso($request->session()->get('matricula')['idCurso']);
                $disciplinasEAD = $this->discEAD->getDisciplinaTurma($request->session()->get('matricula')['idTurma']);
              // dd($request->session()->get('matricula'));
                if($disciplinasEAD->count() > 0){
                    foreach($disciplinasEAD as $ead){
                        $disciplina = $this->disc->find($ead->disciplina_id);
        
                        // verifica se ja existe associação da disciplina ao registro de notas
                        $discMatricula = $this->disciplinaMat->where('alunos_matriculas_id', $idMatricula)->where('disciplinas_id', $ead->disciplina_id)->first();
                        if(!$discMatricula){
                            $this->disciplinaMat->create([
                                'alunos_matriculas_id'  => $idMatricula,
                                'disciplinas_id'        => $disciplina->id
                            ]);
        
                            $discMatricula = $this->disciplinaMat->where('alunos_matriculas_id', $idMatricula)->where('disciplinas_id', $ead->disciplina_id)->first();
                        }
        
                        // verifica registro de nota
                        $discNota = $this->notas->where('matriculas_disciplinas', $discMatricula->id)->first();
                        if(!$discNota){
                            $this->notas->create([
                                'matriculas_disciplinas' => $discMatricula->id
                            ]);
                            $discNota = $this->notas->where('matriculas_disciplinas', $discMatricula->id)->first();
                        }
        
                        // monta array de disciplinas
                        $lnDisciplina = [
                            'idDiscMatricula'   => $discMatricula->id,
                            'nomeDisciplina'    => $disciplina->nomeDisciplina,
                            'percFalta'         => $discNota->percFrequencia,
                            'creditoNota'       =>  $discNota->tipoRegistro
                        ];
        
                        array_push($disciplinas, $lnDisciplina);
                    }
                } 
                break;

        }

        // configuração de inadimplencia                     
        $mensagemInadimplente = null;        
        if($request->session()->get('matricula')['inadimplente'] == 1){                        
            $mensagemInadimplente = 'Prezado aluno, <a href="'.route('boleto.negociacao').'" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }
        

        /**
         * Registra Log de acesso                 
       
        AlunosLog::create([
            'sistema_id' => 3, 
            'alunos_matriculas_id' => $request->session()->get('matricula')['idMatricula'], 
            'modulo' => 1, 
            'acao' => 3, 
            'descAcao' => 'Acessou a tela de frequências.', 
            'ipAcesso' => $request->ip(), 
            'agente' => $request->header('user-agent')
        ]);  */

        // dd($disciplinas);
        
        return view('frequencias.index', compact('disciplinas', 'mensagemInadimplente'));
    }   
    
    


    /**
     * Tela de calendário de aulas
     *
     * @param Request $request
     * @return void
     */
    public function calendarioModulos(Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home.moodle')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }
        $id = $request->session()->get('matricula')['idMatricula'];

        $matricula = $this->matriculas->find($id);
        $listaDisciplinas = $this->disciplinaMat->getDisciplinasMatricula($id);
        $turma = $this->turma->find($matricula->turmas_id);
        $curso = $this->curso->find($turma->cursos_id);
        $disciplinas = [];
        // monta array de disciplinas
        if(count($listaDisciplinas) > 0){
            foreach($listaDisciplinas as $disc){
                // verifica aulas
                $aulas = $this->aula->getAulasTurmaDisciplina($turma->id, $disc->id, $matricula->codAno);
                $lsAulas = [];
                $professor = '';
                $linkBtn = '';
                if(count($aulas) > 0){
                    foreach($aulas as $aln){
                        $lnAula = [
                            'dataAula' => date('d/m/y', strtotime($aln->dataAula)),
                            'horaInicio' => substr($aln->horaInicio, 0, -3),
                            'horaFim' => substr($aln->horaFim, 0, -3)
                        ];

                        array_push($lsAulas, $lnAula);
                    }
                    
                    // seleciona nome do professor
                    if($aln->users_id != ""){
                        $user = $this->usuario->find($aln->users_id);
                        $professor = $user->name;                        
                    }
                }

                $lnDisc = [
                    'idDisc' => $disc->id,
                    'nomeDisciplina' => $disc->nomeDisciplina,
                    'ementaDisciplina' => $disc->ementaDisciplina,
                    'calendario' => $lsAulas,
                    'professor' => $professor,
                ];

                array_push($disciplinas, $lnDisc);
            }
            
        }

        return view('calendario.indexCalendario', compact('disciplinas'));
    }

    /**
     * Tela de calendário de aulas
     *
     * @param Request $request
     * @return void
     */
    public function calendarioModulosSemi(Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home.moodle')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }
        $id = $request->session()->get('matricula')['idMatricula'];
        //dd($id);
        $matricula = $this->matriculas->find($id);
        $listaDisciplinas = $this->disciplinaMat->getDisciplinasMatricula($id);
        $turma = $this->turma->find($matricula->turmas_id);
        $curso = $this->curso->find($turma->cursos_id);
        $disciplinas = [];
        // monta array de disciplinas
        if(count($listaDisciplinas) > 0){
            foreach($listaDisciplinas as $disc){
                // verifica aulas
                $aulas = $this->aula->getAulasTurmaDisciplina($turma->id, $disc->id, $matricula->codAno);
                $lsAulas = [];
                $professor = '';
                $linkBtn = '';
                if(count($aulas) > 0){
                    foreach($aulas as $aln){
                        $lnAula = [
                            'dataAula' => date('d/m/y', strtotime($aln->dataAula)),
                            'horaInicio' => substr($aln->horaInicio, 0, -3),
                            'horaFim' => substr($aln->horaFim, 0, -3)
                        ];

                        array_push($lsAulas, $lnAula);
                    }
                    
                    // seleciona nome do professor
                    if($aln->users_id != ""){
                        $user = $this->usuario->find($aln->users_id);
                        $professor = $user->name;                        
                    }
                }

                $lnDisc = [
                    'idDisc' => $disc->id,
                    'nomeDisciplina' => $disc->nomeDisciplina,
                    'ementaDisciplina' => $disc->ementaDisciplina,
                    'calendario' => $lsAulas,
                    'professor' => $professor,
                ];

                array_push($disciplinas, $lnDisc);
            }
            
        }
        
        return view('calendario.indexCalendarioSemi', compact('disciplinas'));
    }


}
