<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\Alunos_fatura;
use App\Models\Alunos_matricula;

class PagseguroController extends Controller
{

    private $faturas, $matricula;

    public function __construct(Alunos_fatura $fat,
                                Alunos_matricula $mat)
    {
        $this->faturas = $fat;
        $this->matricula = $mat;


    }

    /**
     * Função que realiza o Checkout do Pagamento
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     * @throws \Exception
     */
    public function checkout(Request $request) {

        /**
         * Seta as configurações da API
         */
        \PagSeguro\Library::initialize();
        \PagSeguro\Library::cmsVersion()->setName("SAV")->setRelease("1.0.0");
        \PagSeguro\Library::moduleVersion()->setName("SAV")->setRelease("1.0.0");
        try {
            \PagSeguro\Library::initialize();
        } catch (Exception $e) {
            die($e);
        }
        \PagSeguro\Configuration\Configure::setEnvironment(env('PAGSEGURO_AMBIENTE')); // opc: sandbox ou production
        \PagSeguro\Configuration\Configure::setAccountCredentials(
        /**
         * EMAIL DA CONTA PAGSEGURO
         * @var string $email
         */
            //env('PAGSEGURO_EMAIL'),
            $request->session()->get('matricula')['pagseguro_email'],
            /**
             * TOKEN DA CONTA
             * @var string $accountToken
             */
            //env('PAGSEGURO_TOKEN')
            $request->session()->get('matricula')['pagseguro_token']
        );
        \PagSeguro\Configuration\Configure::setCharset('UTF-8'); // opc: UTF-8, ISO-8859-1
        \PagSeguro\Configuration\Configure::setLog(true, 'storage/logs'); // habilita registro de logs
        try {
            $response = \PagSeguro\Services\Session::create(
                \PagSeguro\Configuration\Configure::getAccountCredentials()
            );
        } catch (Exception $e) {
            die($e->getMEssage());
        }
        /** FIM DA CONFIGURAÇÃO PAGSEGURO **/

        $fatura = $this->faturas->find($request->cod);
        if(!$fatura) {
            return response()->json(['Erro ao localizar fatura!'], 401);
        }
        $aluno = $this->matricula->getMatriculaIDAluno($fatura->alunos_matriculas_id)->first();
        $totalFatura = $fatura->valorFatura - $fatura->totalDesconto;

        $pagto = new \PagSeguro\Domains\Requests\Payment();
        // adiciona itens ao pagamento
        $pagto->addItems()->withParameters(
            $request->cod,
            $request->desc,
            1,
            $totalFatura
        );
        // informa o pagador
        $pagto->setSender(
            $aluno->nomeAluno,
            $aluno->emailAluno,
            'CPF',
            $aluno->cpfAluno
        );
        // informa url de redirecionamento
        $pagto->setRedirectUrl(route('pagseguro.sucesso', [$fatura->id]));
        $pagto->addMetadata('STUDENT_NAME', "$aluno->nomeAluno", 1);
        $pagto->addMetadata('STUDENT_CPF', str_replace(".", "", str_replace("-", "", $aluno->cpfAluno)), 1);

        // informa url de retorno checkin
        $pagto->addParameter('notificationURL', 'http://back.universidade.site/api/pagseguro/checkin');

        $pagto->setCurrency('BRL'); // seta moeda
        $pagto->setReference('LIBPHP000001');

        try {
            $onlyCheckoutCode = true;

            $result = $pagto->register(
                \PagSeguro\Configuration\Configure::getAccountCredentials(),
                $onlyCheckoutCode
            );

            $code = $result->getCode();

            return response()->json($code, 201);

        } catch (Exception $e) {
            die("ERROR: " . $e->getMessage());
        }
    }


    public function sucesso()
    {
        echo '<h1>Ok</h1>';
    }

}
