<?php

namespace App\Http\Controllers;

use App\Helpers\Checklinkfile;
use Illuminate\Http\Request;

use App\Models\Aluno;
use App\Models\Alunos_matricula;
use App\Models\AlunosFatura;
use App\Models\AlunosMatriculasDisciplinas;
use App\Models\Protocolo;
use App\Models\ProtocolosAssunto;
use App\Models\ProtocolosAnexo;
use App\Models\ProtocolosParecer;
use App\Models\ProtocolosParecerAnexo;
use Illuminate\Support\Facades\Storage;

class ProtocolosController extends Controller
{
    private $aluno, $protocolo, $assunto, $matricula, $anexo, $fatura, $parecer, $disciplina;

    public function __construct(
        Aluno $aln,
        Alunos_matricula $mat,
        Protocolo $prot,
        ProtocolosAssunto $ass,
        ProtocolosAnexo $anx,
        ProtocolosParecer $par,
        ProtocolosParecerAnexo $anx2,
        AlunosFatura $fat,
        AlunosMatriculasDisciplinas $disc
    ) {
        $this->aluno = $aln;
        $this->assunto = $ass;
        $this->matricula = $mat;
        $this->protocolo = $prot;
        $this->anexo = $anx;
        $this->parecer = $par;
        $this->anxParecer = $anx2;
        $this->fatura = $fat;
        $this->disciplina = $disc;
    }


    /**
     * Tela inicial de Protocolos do Aluno, via Acesso Moodle
     *
     * @param Request $request
     * @return void
     */
    public function indexMoodle(Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if (!isset($request->session()->get('matricula')['idMatricula'])) {
            return redirect()
                ->route('home.moodle')
                ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        $matricula = $this->matricula->find($request->session()->get('matricula')['idMatricula']);

        $disciplinas = $this->disciplina->getDisciplinasMatriculaModulos($matricula->id);
        $aluno = $this->aluno->find($matricula->alunos_id);
        $protocolos = $this->protocolo->getProtocolosMatricula($matricula->id);


        /**
         * Caso o aluno esteja inadimeplente só mostra os assuntos relacionados a negociação financeira.
         */
        $inadimplente = $matricula->inadimplente;
        if ($inadimplente == 1) {
            $assunto = $this->assunto->getAssuntoProtocoloInadimeplente($matricula->modalidade, $matricula->empresas_id);
        } else {
            $assunto = $this->assunto->getAssuntoProtocolo($matricula->modalidade, $matricula->empresas_id);
        }
        //dd($assunto);
        // configuração de inadimplencia        
        $mensagemInadimplente = null;
        if ($request->session()->get('matricula')['inadimplente'] == 1) {
            $mensagemInadimplente = 'Prezado aluno, <a href="' . route('boleto.negociacao') . '" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }

        return view('protocolos.index', compact('assunto', 'mensagemInadimplente', 'aluno', 'matricula', 'protocolos', 'disciplinas', 'inadimplente'));
    }

    /**
     * Cadastra protocolo
     *
     * @param Request $request
     * @return void
     */
    public function store(Request $request)
    {
        // dd($request->all());
        // retorna dados do assunto selecionado
        //dd($request->protocolo_assuntos_id);
        $assunto = $this->assunto->find($request->protocolo_assuntos_id);

        $valorProtocolo = $assunto->valorProtocolo;
        // caso seja de urgência retorna 
        // verifica se o valor do protocolo é abaixo de 60.00 caso seja da o valor da taxa continua
        // caso não seja valor soma a taxa
        if ($request->nivelUrgencia == 2 && $assunto->valorProtocolo <= '60.00') {
            $valorProtocolo = 60.00;
        } else if ($request->nivelUrgencia == 2 && $assunto->valorProtocolo > '60.00') {
            $valorProtocolo = 60.00 + $assunto->valorProtocolo;
        }

        // verifica se discipina foi passada
        if ($request->disciplina != "") {
            $justificativa  = $request->justificativaProtocolo;
            $justificativa .= "<br /><br /><b>Disciplina:</b> " . $request->disciplina;
        } else {
            $justificativa = $request->justificativaProtocolo;
        }

        // verifica se o nivelUrgencia foi atualizado
        if (!$request->nivelUrgencia) {
            $request->nivelUrgencia = 1;
        }

        /*
         * verifica se o valor do protocolo é 0.00
         * Caso seja 0.00 o status do protocolo passa a ser 4 = isento
         * Caso não seja status fica 0 = aguardando pagamento
         * Porém seele for URGENTE passa a ter o valor da taxa de Urgência.
         */
        if ($assunto->valorProtocolo == '0.00' && $request->nivelUrgencia == 1) {
            $statusProtocolo = 1;

            // calcula o prazo de resposta com base na data de solicitação
            $dataPagamento = date('Y-m-d');
            $diasPrazo = $assunto->prazoResposta;
            $dataAtual = date('Y-m-d');
            //$dataPrazo = date('Y-m-d', strtotime("+$diasPrazo days", strtotime($dataAtual)));            

            //$dataPrazo = $this->validaVcto($dataPrazo);
            //$dataPrazo = $this->calculaPrazoDiasUteis($dataPagamento, $diasPrazo);
            $dataPrazo = date('Y-m-d', strtotime("+{$diasPrazo} days", strtotime($dataPagamento)));
            $statusFatura = 4; // isenta a fatura

            // caso seja solicitado com valor de urgência
        } else if ($assunto->valorProtocolo == '0.00' && $request->nivelUrgencia == 2) {
            $valorProtocolo = 60.00;
            $dataPagamento = '';
            $dataPrazo = '';
            $statusProtocolo = 0;
            $statusFatura = 0;
        } else {
            $statusProtocolo = 0;
            $dataPrazo = '';
            $dataPagamento = '';
            $statusFatura = 0;
        }

        // cria código do protocolo
        $codigo = $this->getCodigo();

        $dados = [
            'alunos_matriculas_id'      => $request->session()->get('matricula')['idMatricula'],
            'protocolo_assuntos_id'     => $assunto->id,
            'codigoProtocolo'           => $codigo,
            'justificativaProtocolo'    => $justificativa,
            'nivelUrgencia'             => $request->nivelUrgencia,
            'dataPagamento'             => $dataPagamento,
            'prazoResposta'             => $dataPrazo,
            'emAtraso'                  => 0,
            'statusProtocolo'           => $statusProtocolo,
            'situacaoProtocolo'         => 0
        ];

        $response = $this->protocolo->create($dados);

        if ($response) {

            // verifica se passou algum arquivo
            if ($request->hasFile('upload') && $request->file('upload')->isValid()) {
                $pastaDestino   = 'arquivos/protocolo/';
                $nomeArquivo    = $codigo . "-" . kebab_case($request->file('upload')->getClientOriginalName()); //define nome
                $extensao       = $request->file('upload')->extension(); // pega a extensão do arquivo
                // $novoNome       = "{$nomeArquivo}.{$extensao}";
                $novoNome       = "{$nomeArquivo}";

                /**************************************************
                 * a lógica a seguir trata sa transição de upload de arquivos para a central de documentos
                 ***************************************************/
                if (env('C_ACTIVE') == 0) {
                    $upload         = $request->file('upload')->storeAs('arquivos/protocolo', $novoNome);
                } else {
                    $upload = Storage::disk('ftp')->put($pastaDestino .  $novoNome, fopen($request->file('upload'), 'r+'));
                }

                if (!$upload) {
                    $response->delete();
                    redirect()->back()->with("warning", "Ocorreu uma falha no upload do arquivo, tente outra vez!");
                }
                // registra no banco
                $ddFile = [
                    'protocolos_id' => $response->id,
                    'nomeArquivo'   => $novoNome
                ];

                $this->anexo->create($ddFile);
            }

            // registra na tabela ALUNOS_FATURAS a fatura do protocolo
            $dadosFatura = [
                'alunos_matriculas_id'  => $request->session()->get('matricula')['idMatricula'],
                'codFatura'             => $codigo,
                'dataVcto'              =>  $this->validaVcto(date('Y-m-d', strtotime('+120 hours'))),
                'valorFatura'           => $valorProtocolo,
                'valorDesconto'         => 0.00,
                'valorDesconto2'        => 0.00,
                'qtdeParcela'           => 1,
                'parcelaCorrente'       => 1,
                'tipoPagto'             => 2,
                'statusFatura'          => $statusFatura,
                'observacoes'           => 'Boleto ref. ao Protocolo num.: ' . $codigo . ' - ' . $assunto->tituloAssunto,
                'emAtraso'              => 1,
                'registradaBco'         => 0,
                'tipoFatura'            => 2
            ];
            $this->fatura->create($dadosFatura);

            return redirect()
                ->route('moodle.protocolos')
                ->with('success', 'Protocolo registrado com sucesso!');
        } else {
            return redirect()
                ->back()
                ->with('error', 'Erro ao registrar protocolo, por favor tente novamente!');
        }
    }

    /**
     * Lista dados de um determinado Protocolo
     *
     * @param integer $id
     * @return void
     */
    public function showMoodle(int $id, Request $request)
    {
        $protocolo = $this->protocolo->getProtocoloID($id);
        $anexos = $this->anexo->where('protocolos_id', $id)->get();
        $parecer = $this->parecer->getParecerProtocolo($id);
        $lsParecer = $this->parecer->getParecerProtocolo($id);
        $parecer = [];
        // verifica se parecer possui anexo
        if (count($lsParecer) > 0) {
            foreach ($lsParecer as $par) {
                $nomeArquivo = '';
                $anexo = $this->anxParecer->where('protocolos_parecer_id', $par->id)->first();
                if ($anexo) {
                    $nomeArquivo    = $anexo->nomeArquivo;
                    $fileLink       = new Checklinkfile($nomeArquivo, 2);
                }

                $lnPar = [
                    'name'          => $par->name,
                    'descParecer'   => $par->descParecer,
                    'anexo'         => $nomeArquivo,
                    'created_at'    => $par->created_at,
                ];

                if ($nomeArquivo) {
                    $lnPar['link'] = $fileLink->getLink();
                }


                array_push($parecer, $lnPar);
            }
        }

        // configuração de inadimplencia        
        $mensagemInadimplente = null;
        if ($request->session()->get('matricula')['inadimplente'] == 1) {
            $mensagemInadimplente = 'Prezado aluno, <a href="' . route('boleto.negociacao') . '" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }

        if ($anexos) {
            foreach ($anexos as $key => $anexo) {
                $fileLink = new Checklinkfile($anexo->nomeArquivo, 2, $request->session()->get('matricula')['idMatricula']);
                $anexos[$key]->link = $fileLink->getLink();
            }
        }

        return view('protocolos.show', compact('protocolo', 'anexos', 'parecer', 'mensagemInadimplente'));
    }

    /**
     * Retorna o prazo em dias e preço do Procolo
     *
     * @param Request $request
     * @return void
     */
    public function slcAssunto(Request $request)
    {
        $assunto = $this->assunto->find($request->assunto_id);
        return $assunto;
    }

    /**
     * Gera Código da Solicitação
     * Ex: 2018122100012
     * Onde:
     * - 2018 => ano atual;
     * - 12 => mês atual;
     * - 21 => dia da solicitação;
     * - 00012 => ID corrente do registro na base de dados.
     *
     * @return void
     */
    private function getCodigo()
    {
        $ultimoReg = $this->protocolo->all()->last();
        if ($ultimoReg) {
            $id = $ultimoReg->id + 1;
        } else {
            $id = 1;
        }
        $ano = date('Y');
        $mes = date('m');
        $dia = date('d');
        return $ano . $mes . $dia . str_pad($id, 5, 0, STR_PAD_LEFT);
    }


    /**
     * Função que valida as datas de vencimentos de pazos, para que elas não caiam em finais de semana
     * $dtVcto = yyyy-mm-dd
     *
     * @param [type] $dtVcto
     * @return void
     */
    public function validaVcto($dtVcto)
    {
        // desmembra data
        $data = explode('-', $dtVcto);
        // transforma a data para tempo para calculos e conversões
        $dtTime = mktime(0, 0, 0, $data[1], $data[2], $data[0]);

        // verifica qual o dia da semana a data caiu
        // caso seja domingo adiciona 1 dia para cair na segunda
        // caso seja sábado subtrai 1 dia para cair na sexta
        $diaSem = date('w', $dtTime);
        switch ($diaSem) {
                // domingo
            case 0:
                $difData = intval($data[2]) + 1;
                break;
                // sábado
            case 6:
                $difData = intval($data[2]) + 2;
                break;
                // mantém mesma data
            default:
                $difData = $data[2];
                break;
        }
        // calcula nova data
        $nwTime = mktime(0, 0, 0, $data[1], $difData, $data[0]);
        $novaData = date('Y-m-d', $nwTime);

        return $novaData;
    }


    /***********************************************************************
     * ALGORITMO DE CÁLCULO DE DATAS ÚTEIS
     * Autor: Rafael Moura
     * Versão: 1.0 
     **********************************************************************/
    /**
     * Função que cálcula dias úteis
     *
     * @param date $aPartirDe
     * @param int $quantidadeDeDias
     * @return void
     */
    public function calculaPrazoDiasUteis($aPartirDe, $quantidadeDeDias)
    {
        //$aPartirDe = '17-04-2019';
        //$quantidadeDeDias = 10;
        $dateTime = new \DateTime($aPartirDe);

        $listaDiasUteis = [];
        $contador = 0;
        while ($contador < $quantidadeDeDias) {
            $dateTime->modify('+1 weekday'); // adiciona um dia pulando finais de semana
            $data = $dateTime->format('Y-m-d');
            if (!$this->isFeriado($data)) {
                $listaDiasUteis[] = $data;
                $contador++;
            }
        }
        $someArray = json_decode(json_encode($listaDiasUteis), true);
        $final = end($someArray);
        $dataFinal = date('Y-m-d', strtotime(str_replace('-', '/', $final)));
        return $dataFinal;
    }

    public function isFeriado($data)
    {
        $listaFeriado = $this->getListaDiasFeriado(date('Y', strtotime($data)));
        if (isset($listaFeriado[$data])) {
            return true;
        }
        return false;
    }

    public function getListaDiasFeriado($ano = null)
    {

        if ($ano === null) {
            $ano = intval(date('Y'));
        }

        $pascoa = easter_date($ano); // retorna data da pascoa do ano especificado
        $diaPascoa = date('j', $pascoa);
        $mesPacoa = date('n', $pascoa);
        $anoPascoa = date('Y', $pascoa);

        $feriados = [
            // Feriados nacionais fixos
            mktime(0, 0, 0, 1, 1, $ano),   // Confraternização Universal
            mktime(0, 0, 0, 4, 21, $ano),  // Tiradentes
            mktime(0, 0, 0, 5, 1, $ano),   // Dia do Trabalhador
            mktime(0, 0, 0, 9, 7, $ano),   // Dia da Independência
            mktime(0, 0, 0, 10, 12, $ano), // N. S. Aparecida
            mktime(0, 0, 0, 11, 2, $ano),  // Todos os santos
            mktime(0, 0, 0, 11, 15, $ano), // Proclamação da republica
            mktime(0, 0, 0, 12, 25, $ano), // Natal
            //
            // Feriados variaveis
            mktime(0, 0, 0, $mesPacoa, $diaPascoa - 48, $anoPascoa), // 2º feria Carnaval
            mktime(0, 0, 0, $mesPacoa, $diaPascoa - 47, $anoPascoa), // 3º feria Carnaval 
            mktime(0, 0, 0, $mesPacoa, $diaPascoa - 2, $anoPascoa),  // 6º feira Santa  
            mktime(0, 0, 0, $mesPacoa, $diaPascoa, $anoPascoa),      // Pascoa
            mktime(0, 0, 0, $mesPacoa, $diaPascoa + 60, $anoPascoa), // Corpus Christ
        ];

        sort($feriados);

        $listaDiasFeriado = [];
        foreach ($feriados as $feriado) {
            $data = date('Y-m-d', $feriado);
            $listaDiasFeriado[$data] = $data;
        }

        return $listaDiasFeriado;
    }

    /**************************************************************************
     * FIM DO ALGORITMO
     *************************************************************************/
}
