<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class AlunosMatriculasDisciplinas extends Model
{
    protected $fillable = ['alunos_matriculas_id', 'disciplinas_id'];
    
    /**
     * Lista disciplinas associadas a uma matrícula e relacionada ao calendário de aulas
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getDisciplinasMatricula(int $idMatricula)
    {
        
        return $this->join('disciplinas', 'disciplinas.id', 'alunos_matriculas_disciplinas.disciplinas_id')
                    ->join('alunos_matriculas', 'alunos_matriculas.id', 'alunos_matriculas_disciplinas.alunos_matriculas_id')
                    ->join('turmas_disciplinas_aulas', 'turmas_disciplinas_aulas.disciplinas_id', 'alunos_matriculas_disciplinas.disciplinas_id')
                    ->where('alunos_matriculas.id', $idMatricula)
                    ->groupBy('turmas_disciplinas_aulas.disciplinas_id')
                    ->select('alunos_matriculas_disciplinas.id as idDisc', 'turmas_disciplinas_aulas.id as idAula', 'turmas_disciplinas_aulas.turmas_id', 'disciplinas.id as idDisciplina', 'disciplinas.*', 'turmas_disciplinas_aulas.users_id as idDocente')
                    ->orderBy('turmas_disciplinas_aulas.dataAula', 'asc')
                    ->get();
    }

    /**
     * Lista disciplinas associadas a uma matrícula e relacionada ao calendário de aulas para Feedback
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getDisciplinasMatriculaFeedback(int $idMatricula, int $idTurma, $codAno)
    {
        
        return $this->join('turmas_disciplinas_aulas', 'turmas_disciplinas_aulas.disciplinas_id', 'alunos_matriculas_disciplinas.disciplinas_id')
                    ->join('disciplinas', 'disciplinas.id', 'turmas_disciplinas_aulas.disciplinas_id')
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $idMatricula)
                    ->where('turmas_disciplinas_aulas.turmas_id', $idTurma)
                    ->where('turmas_disciplinas_aulas.anoExercicio', $codAno)
                    ->groupBy('turmas_disciplinas_aulas.disciplinas_id')
                    ->select('alunos_matriculas_disciplinas.id as idDisc', 'turmas_disciplinas_aulas.id as idAula', 'turmas_disciplinas_aulas.turmas_id', 'disciplinas.id as idDisciplina', 'disciplinas.*', 'turmas_disciplinas_aulas.users_id as idDocente')
                    ->get();
    }

    /**
     * Lista disciplinas associadas a uma matrícula - grade de disciplinas por matrícula
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getDisciplinasMatriculaModulos(int $idMatricula)
    {
        
        return $this->join('disciplinas', 'disciplinas.id', 'alunos_matriculas_disciplinas.disciplinas_id')
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $idMatricula)
                    ->select('alunos_matriculas_disciplinas.id as idDisc',  'disciplinas.id as idDisciplina', 'disciplinas.*')
                    ->get();                
    }
}
