<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class AlunosMatriculasNota extends Model
{
    protected $fillable = ['matriculas_disciplinas', 'dataAvaliacao', 'descAvaliacao', 'valorNota'];

    /**
     * Lista Notas das Disciplinas de uma Matrícula
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getNotaMatricula(int $idMatricula)
    {

        return $this->join('alunos_matriculas_disciplinas', 'alunos_matriculas_disciplinas.id', 'alunos_matriculas_notas.matriculas_disciplinas')
                    ->join('disciplinas', 'disciplinas.id', 'alunos_matriculas_disciplinas.disciplinas_id')
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $idMatricula)
                    ->select('alunos_matriculas_notas.matriculas_disciplinas as idDisc', 'disciplinas.id as disciplina_id', 'disciplinas.nomeDisciplina', 'disciplinas.cargaHoraria', 'alunos_matriculas_notas.*')
                    ->groupBy('alunos_matriculas_notas.matriculas_disciplinas')
                    ->get();

    }

    /**
     * Lista Frequencia Associada das Disciplinas de uma Matrícula
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getNotaMatriculaFrequencia(int $idMatricula)
    {
        return $this->join('alunos_matriculas_disciplinas', 'alunos_matriculas_disciplinas.id', 'alunos_matriculas_notas.matriculas_disciplinas')
                    ->join('disciplinas', 'disciplinas.id', 'alunos_matriculas_disciplinas.disciplinas_id')
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $idMatricula)
                    ->select('disciplinas.nomeDisciplina', 'alunos_matriculas_notas.*')
                    ->groupBy('alunos_matriculas_notas.matriculas_disciplinas')
                    ->orderBy('disciplinas.nomeDisciplina', 'asc')
                    ->orderBy('alunos_matriculas_notas.percFrequencia', 'asc')
                    ->groupBy('alunos_matriculas_notas.matriculas_disciplinas')
                    ->get();
    }

    /**
     * Lista Notas do Aluno relacionado a disciplina
     *
     * @param integer $idMatricula
     * @param integer $idDisciplina
     * @return void
     */
    public function getNotaDisciplinaAluno(int $idMatricula, int $idDisciplina)
    {
        return $this->join('alunos_matriculas_disciplinas', 'alunos_matriculas_disciplinas.id', 'alunos_matriculas_notas.matriculas_disciplinas')
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $idMatricula)
                    ->where('alunos_matriculas_disciplinas.disciplinas_id', $idDisciplina)
                    ->get();
    }

    /**
     * Lista Notas de um aluno, conforme a disciplina informada
     *
     * @param integer $idMatricula
     * @param integer $idDisciplina
     * @return void
     */
    public function getListaNotasAlunoDisciplina(int $idMatricula, int $idDisciplina)
    {
        return $this->join('alunos_matriculas_disciplinas', 'alunos_matriculas_disciplinas.id', 'alunos_matriculas_notas.matriculas_disciplinas')
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $idMatricula)
                    ->where('alunos_matriculas_disciplinas.disciplinas_id', $idDisciplina)
                    ->get();
    }

    public function getListaNotasAlunoFeedback(int $idMatricula, int $idDisciplina)
    {
        return $this->join('alunos_matriculas_disciplinas', 'alunos_matriculas_disciplinas.id', 'alunos_matriculas_notas.matriculas_disciplinas')
            ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $idMatricula)
            ->where('alunos_matriculas_disciplinas.disciplinas_id', $idDisciplina)
            ->first();
    }

}
