<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class AlunosUnidadesRecurso extends Model
{
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = ['alunos_matriculas_id', 'unidades_recursos_id', 'statusAcesso', 'pontosGame', 'dataAcesso'];

    protected $connection = 'mysql_sav';

    /**
     * Verifica dados de Recurso acessado pelo aluno
     *
     * @param integer $idMatricula
     * @param integer $idRecurso
     * @return object
     */
    public function getAlunoRecurso(int $idMatricula, int $idRecurso)
    {
        return $this->where('alunos_matriculas_id', $idMatricula)
                    ->where('unidades_recursos_id', $idRecurso)
                    ->first();
    }

    /**
     * Lista recursos relacionados aos alunos conforme status de acesso informado
     *
     * @param integer $idMatricula
     * @param integer $status
     * @return mixed
     */
    public function getAlunoRecursoStatusAcesso(int $idMatricula, int $status)
    {
        return $this->where('alunos_matriculas_id', $idMatricula)
                    ->where('statusAcesso', $status)
                    ->groupBy('alunos_matriculas_id')
                    ->get();
    }

    /**
     * Retorna módulos da disciplina por status de acessado
     *
     * @param integer $idMatricula
     * @param integer $idDisciplina
     * @return mixed
     */
    public function getAlunoRecursoAcesso(int $idMatricula, int $idDisciplina, int $status = null)
    {
        $lista = $this->join('disciplinas_unidades_recursos', 'disciplinas_unidades_recursos.id', 'alunos_unidades_recursos.unidades_recursos_id')
                    ->join('disciplinas_unidades', 'disciplinas_unidades.id', 'disciplinas_unidades_recursos.disciplinas_unidades_id')
                    ->join('disciplinas_ead', 'disciplinas_ead.id', 'disciplinas_unidades.disciplinas_ead_id')
                    ->where('disciplinas_ead.disciplina_id', $idDisciplina)
                    ->where('disciplinas_unidades.statusUnidade', '1') 
                    ->where('alunos_unidades_recursos.alunos_matriculas_id', $idMatricula)
                    ->where('disciplinas_unidades_recursos.statusRecurso', '1')
                    ->where('disciplinas_unidades_recursos.tipoRecurso', '!=', '1');

        // verifica se parametro de status foi passado
        if($status != null){
            $lista->where('alunos_unidades_recursos.statusAcesso', $status);
        }

        return $lista->get();
    }

    /**
     * Retorna lista de acessos a recursos
     * É passado um vetor de parametros para filtrar os resultados
     *
     * @param array $ln
     * @return void
     */
    public function getAlunoRecursosAcessos(array $ln)
    {
        $lista = $this->join('disciplinas_unidades_recursos', 'disciplinas_unidades_recursos.id', 'alunos_unidades_recursos.unidades_recursos_id')
                    ->join('disciplinas_unidades', 'disciplinas_unidades.id', 'disciplinas_unidades_recursos.disciplinas_unidades_id')
                    ->join('disciplinas_ead', 'disciplinas_ead.id', 'disciplinas_unidades.disciplinas_ead_id')
                    ->where('disciplinas_unidades_recursos.statusRecurso', '1')
                    ->where('disciplinas_unidades_recursos.tipoRecurso', '!=', '1');

        // verifica se data de periodo foi passado
        if(isset($ln['dataInicial']) && isset($ln['dataFinal'])){
            $lista->whereBetween('alunos_unidades_recursos.dataAcesso', [$ln['dataInicial'], $ln['dataFinal']]);
        }

        // verifica se parametro de status foi passado
        if(isset($ln['status'])){
            $lista->where('alunos_unidades_recursos.statusAcesso', $ln['status']);
        }

        return $lista->orderBy('alunos_unidades_recursos.dataAcesso', 'asc')->get();
    }

    /**
     * Lista dados de ultimo acesso do aluno
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getUltimoAcessoAluno(int $idMatricula)
    {
        return $this->where('alunos_matriculas_id', $idMatricula)
                    ->whereNotNull('dataAcesso')
                    ->orderBy('dataAcesso', 'desc')
                    ->first();
    }


    public function getDadosRecurso(int $idRecurso)
    {
        return $this->join('disciplinas_unidades_recursos', 'disciplinas_unidades_recursos.id', 'alunos_unidades_recursos.unidades_recursos_id')
                    ->join('disciplinas_unidades', 'disciplinas_unidades.id', 'disciplinas_unidades_recursos.disciplinas_unidades_id')
                    ->join('disciplinas_ead', 'disciplinas_ead.id', 'disciplinas_unidades.disciplinas_ead_id')
                    ->where('alunos_unidades_recursos.id', $idRecurso)
                    ->first();

    }

    public function getAcessoRecursoEvasao(int $idMatricula, $data)
    {
        return $this->where('alunos_matriculas_id', $idMatricula)
            ->where('dataAcesso', '>=', $data)
            ->get();
    }

    public function getAcessoForum(string $nome)
    {
        return $this->join('disciplinas_unidades_recursos', 'disciplinas_unidades_recursos.id', 'alunos_unidades_recursos.unidades_recursos_id')
                    ->join('disciplinas_unidades', 'disciplinas_unidades.id', 'disciplinas_unidades_recursos.disciplinas_unidades_id')
                    ->join('disciplinas_ead', 'disciplinas_ead.id', 'disciplinas_unidades.disciplinas_ead_id')
                    ->where('disciplinas_unidades_recursos.tipoRecurso', '7')
                    //->where('disciplinas_unidades_recursos.nomeRecurso','LIKE', '%Estudo de caso%')
                    ->where('alunos_unidades_recursos.statusAcesso','1')
                   // ->whereNotNull('disciplinas_ead.turmas_id')
                   ->Select('alunos_unidades_recursos.alunos_matriculas_id', 'unidades_recursos_id', 'turmas_id','alunos_unidades_recursos.unidades_recursos_id','disciplinas_ead.disciplina_id')
                    //->paginate(10);
                    ->get();

    }
}
