<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class AlunosUnidadesRecursoAvaliacao extends Model
{

    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'alunos_unidades_recursos_avaliacao';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = ['alunos_unidades_recursos_id', 'dataInicio', 'dataTermino', 'valorNotaAv', 'notaFinal','statusAvaliacao'];

    protected $connection = 'mysql_sav';

    /**
     * Undocumented function
     *
     * @param integer $idAvaliacao
     * @return void
     */
    public function getDadosGeraisAvaliacao(int $idAvaliacao)
    {
        return $this->join('alunos_unidades_recursos', 'alunos_unidades_recursos_avaliacao.alunos_unidades_recursos_id', 'alunos_unidades_recursos.id')
                    ->join('disciplinas_unidades_recursos', 'disciplinas_unidades_recursos.id', 'alunos_unidades_recursos.unidades_recursos_id')
                    ->join('recursos_avaliacoes', 'recursos_avaliacoes.unidades_recursos_id', 'disciplinas_unidades_recursos.id')
                    ->where('alunos_unidades_recursos_avaliacao.id', $idAvaliacao)
                    ->select('alunos_unidades_recursos_avaliacao.id as idProva', 'alunos_unidades_recursos_avaliacao.*',
                        'alunos_unidades_recursos_avaliacao.statusAvaliacao as stsAvaliacao', 'recursos_avaliacoes.*')
                    ->first();
    }

    /**
     * Lista dados da última tentativa
     *
     * @param integer $idAvaliacao
     * @return object
     */
    public function getUltimaTentativaAvaliacao(int $idAvaliacao)
    {
        return $this->where('alunos_unidades_recursos_id', $idAvaliacao)
                    ->orderBy('id', 'desc')
                    ->first();
    }

    /**
     * Lista todas as tentativas de avaliação do aluno
     *
     * @param integer $idRecurso
     * @return void
     */
    public function getAlunosAvaliacao(int $idRecurso)
    {
        return $this->join('alunos_unidades_recursos', 'alunos_unidades_recursos.id', 'alunos_unidades_recursos_avaliacao.alunos_unidades_recursos_id')
                    ->where('alunos_unidades_recursos.unidades_recursos_id', $idRecurso)
                    ->orderBy('alunos_unidades_recursos_avaliacao.dataInicio', 'asc')
                    ->get();
    }

    /**
     * Traz a maior nota da avaliação
     *
     * @param integer $idAlnRecurso
     * @return void
     */
    public function getMaiorNota(int $idAlnRecurso)
    {
        return $this->where('alunos_unidades_recursos_id', $idAlnRecurso)
                    ->orderBy('valorNotaAv', 'desc')
                    ->orderBy('id', 'desc')
                    ->first();
    }

    /**
     * Lista notas válidas de um determinado aluno por disciplina cursada
     *
     * @param integer $idMatricula
     * @param integer $idDisciplina
     * @return void
     */
    public function getNotasDisciplina(int $idMatricula, int $idDisciplina)
    {
        return $this->join('alunos_unidades_recursos', 'alunos_unidades_recursos.id', 'alunos_unidades_recursos_avaliacao.alunos_unidades_recursos_id')
                    ->join('disciplinas_unidades_recursos', 'disciplinas_unidades_recursos.id', 'alunos_unidades_recursos.unidades_recursos_id')
                    ->join('disciplinas_unidades', 'disciplinas_unidades.id', 'disciplinas_unidades_recursos.disciplinas_unidades_id')
                    ->join('disciplinas_ead', 'disciplinas_ead.id', 'disciplinas_unidades.disciplinas_ead_id')
                    ->where('disciplinas_ead.disciplina_id', $idDisciplina)
                    ->where('alunos_unidades_recursos.alunos_matriculas_id', $idMatricula)
                    ->where('alunos_unidades_recursos_avaliacao.notaFinal', 1)
                    ->orderBy('alunos_unidades_recursos_avaliacao.valorNotaAv', 'DESC')
                    ->select('alunos_unidades_recursos_avaliacao.*', 'disciplinas_unidades_recursos.nomeRecurso','disciplinas_unidades.nomeUnidade')
                    ->get();
    }

    /**
     * Lista avaliações realizadas por um determinado aluno
     *
     * @param integer $idMatricula
     * @param integer $idDisciplina
     * @return void
     */
    public function getAvaliacoesDisciplina(int $idMatricula, int $idDisciplina)
    {
        return $this->join('alunos_unidades_recursos', 'alunos_unidades_recursos.id', 'alunos_unidades_recursos_avaliacao.alunos_unidades_recursos_id')
                    ->join('disciplinas_unidades_recursos', 'disciplinas_unidades_recursos.id', 'alunos_unidades_recursos.unidades_recursos_id')
                    ->join('disciplinas_unidades', 'disciplinas_unidades.id', 'disciplinas_unidades_recursos.disciplinas_unidades_id')
                    ->join('disciplinas_ead', 'disciplinas_ead.id', 'disciplinas_unidades.disciplinas_ead_id')
                    ->where('disciplinas_ead.disciplina_id', $idDisciplina)
                    ->where('alunos_unidades_recursos.alunos_matriculas_id', $idMatricula)
                    ->select('alunos_unidades_recursos.id as idAlnUnidRecurso','alunos_unidades_recursos_avaliacao.*', 'disciplinas_unidades_recursos.id as idUnidRecurso', 'disciplinas_unidades_recursos.nomeRecurso','disciplinas_unidades.nomeUnidade')
                    ->get();
    }

    /**
     * Verifica se há questões não preenchidas na atividade
     *
     * @param integer $idAtividade
     * @return void
     */
    public function getValidaFinalizacaoAtividade(int $idAtividade)
    {
        return $this->join('alunos_unidades_recursos_av_questoes', 'alunos_unidades_recursos_av_questoes.alunos_unidades_recursos_avaliacao_id', 'alunos_unidades_recursos_avaliacao.id')
                    ->where('alunos_unidades_recursos_avaliacao.id', $idAtividade)
                    ->whereNull('alunos_unidades_recursos_av_questoes.questaoCorreta')
                    ->get();
    }
}
