<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class ComunicadosMensagens extends Model
{
    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'comunicados_mensagens';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
     protected $fillable = ['users_id', 'assuntoComunicado', 'msgComunicado', 'dataPublicacao', 'statusComunicado'];

    /**
     * Lista mensagens pros alunos de acordo com a matrícula logada
     *
     * @return void
     */
    public function getMensagensAluno(int $idMatricula)
    {
        return $this->join('comunicados_enviados','comunicados_enviados.comunicados_mensagens_id', 'comunicados_mensagens.id')
                    ->join('users', 'users.id', 'comunicados_mensagens.users_id')
                    ->where('comunicados_enviados.alunos_matriculas_id', $idMatricula)
                    ->where('comunicados_enviados.statusLeitura', '0') 
                    ->orderBy('comunicados_mensagens.dataPublicacao', 'desc')
                    ->select('comunicados_mensagens.*', 'comunicados_enviados.dataAbertura', 'comunicados_enviados.statusLeitura', 'users.name')
                    ->get();

    }

    /**
     * Lista todas as mensagens do aluno
     *
     * @return void
     */
    public function getComunicadosAluno(int $idMatricula)
    {
        $data = date("Y-m-d");
        return $this->join('comunicados_enviados','comunicados_enviados.comunicados_mensagens_id', 'comunicados_mensagens.id')
                    ->join('users', 'users.id', 'comunicados_mensagens.users_id')
                    ->where('comunicados_enviados.alunos_matriculas_id', $idMatricula)
                    //->where('comunicados_enviados.statusLeitura', '0')
                    ->where('dataPublicacao' ,'<=',date("Y-m-d") )
                    ->orderBy('comunicados_mensagens.dataPublicacao', 'desc')
                    ->select('comunicados_mensagens.*', 'comunicados_enviados.dataAbertura', 'comunicados_enviados.statusLeitura', 'users.name', 'users.tipoUsuario')
                    ->get();

    }

    /**
     * Exibe Comunicado do Aluno, com base no id da Matricula e id do Comunicado
     *
     * @param [type] $idMatricula
     * @param [type] $idAluno
     * @return void
     */
    public function getMensagemAluno($idMatricula, $idComunicado)
    {
        return $this->join('comunicados_enviados','comunicados_enviados.comunicados_mensagens_id', 'comunicados_mensagens.id')
                    ->join('users', 'users.id', 'comunicados_mensagens.users_id')
                    ->where('comunicados_enviados.alunos_matriculas_id', $idMatricula)
                    ->where('comunicados_mensagens.id', $idComunicado)
                    ->orderBy('comunicados_mensagens.dataPublicacao', 'desc')
                    ->select('comunicados_mensagens.*', 'comunicados_enviados.dataAbertura', 'comunicados_enviados.statusLeitura', 'users.name', 'users.email')
                    ->first();
    }

}
