<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

use DB;

class FeedbackRespostas extends Model
{
    /**
     * The connection name for the model.
     *
     * @var string
     */
    protected $connection = 'mysql';

    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'feedback_respostas';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = ['id', 'pesquisas_alunos_id', 'pesquisas_perguntas_id', 'disciplinas_id', 'respostaAluno', 'comentario', 'created_at', 'updated_at'];


    /**
     * Lista empresas por usuario
     *
     * @param int $idUser
     * @return mixed
     */
    public function getVerifica(int $iddisciplina, int $idAluno)
    {
        return $this->where('disciplinas_ead_id', $iddisciplina)
            ->where('alunos_matriculas_id', $idAluno)
            ->get();
    }


    public function getLista(int $idmat, array $idpesquisa,  int $iddisciplina)
    {
        return $this->join('feedback_perguntas', 'feedback_perguntas.id', 'pesquisas_perguntas_id')
            ->where('disciplinas_id', $iddisciplina)
            ->where('pesquisas_alunos_id', $idmat)
            ->whereIn('pesquisas_perguntas_id', $idpesquisa)
            ->select('feedback_respostas.id', 'feedback_perguntas.perguntaPesquisa', 'feedback_respostas.disciplinas_id', 'feedback_perguntas.estiloPergunta')
            ->get();
    }

    public function getValidar(int $aluno, int $disciplina, int $valor)
    {
        return $this->join('feedback_alunos', 'feedback_alunos.id', 'feedback_respostas.pesquisas_alunos_id')
            ->where('feedback_alunos.alunos_matriculas_id', $aluno)
            ->where('feedback_respostas.disciplinas_id', $disciplina)
            //->where('feedback_respostas.respostaAluno', $valor)
            ->count();
        //->select(DB::raw('count(id) as id') );


    }

    public function getResposta(int $aluno, int $disciplina, int $valor)
    {
        return $this->join('feedback_alunos', 'feedback_alunos.id', 'feedback_respostas.pesquisas_alunos_id')
            ->where('feedback_alunos.alunos_matriculas_id', $aluno)
            ->where('feedback_respostas.disciplinas_id', $disciplina)
            ->where('feedback_respostas.respostaAluno', $valor)
            ->limit(1)
            ->get();
    }

    /**
     * Lista dados da turma e curso pelo id da turma
     *
     * @param int $idTurma
     * @return mixed
     */
    public function getTurmaFeedback($dataInicial, $dataFinal, int $modalidade)
    {
        return $this->join('feedback_alunos', 'feedback_alunos.id', 'pesquisas_alunos_id')
            ->join('alunos_matriculas', 'alunos_matriculas.id', 'feedback_alunos.alunos_matriculas_id')
            ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
            ->join('cursos', 'cursos.id', 'turmas.cursos_id')
            ->whereNotIn('feedback_respostas.respostaAluno', [0, 5])
            ->whereBetween('feedback_respostas.created_at', [$dataInicial . " 00:00:00", $dataFinal . " 23:59:59"])
            ->where('turmas.modalidadeTurma', $modalidade)
            ->select('turmas.*', 'cursos.siglaCurso', 'cursos.nomeCurso', 'cursos.empresas_id')
            ->groupby('turmas.id')
            ->get();
    }

    public function getDisciplinasFeedbackTurma(int $turma, $dataInicial, $dataFinal, $modalidade)
    {
        return $this->join('feedback_alunos', 'feedback_alunos.id', 'pesquisas_alunos_id')
            ->join('alunos_matriculas', 'alunos_matriculas.id', 'feedback_alunos.alunos_matriculas_id')
            ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
            ->join('cursos', 'cursos.id', 'turmas.cursos_id')
            ->join('disciplinas', 'disciplinas.id', 'feedback_respostas.disciplinas_id')
            ->whereNotIn('feedback_respostas.respostaAluno', [0, 5])
            //->where('turmas.id', $turma)
            ->where('turmas.modalidadeTurma', $modalidade)
            ->whereBetween('feedback_respostas.created_at', [$dataInicial . " 00:00:00", $dataFinal . " 23:59:59"])
            ->select('disciplinas.id', 'disciplinas.nomeDisciplina', 'turmas.nomeTurma', 'cursos.siglaCurso', 'cursos.nomeCurso', 'turmas.id as turmaId')
            ->orderby('cursos.nomeCurso')
            ->groupby('disciplinas.id')
            ->get();
    }

    public function getRelatorio(string $dataInicial, string $dataFinal, int $modalidade)
    {
        $query = $this->join('feedback_alunos', 'feedback_alunos.id', 'feedback_respostas.pesquisas_alunos_id')
            ->join('alunos_matriculas', 'alunos_matriculas.id', 'feedback_alunos.alunos_matriculas_id')
            ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
            ->join('cursos', 'cursos.id', 'turmas.cursos_id')
            ->select(
                'feedback_respostas.disciplinas_id',
                (DB::raw(
                    'count(feedback_respostas.id) as count_id, 
                    sum(feedback_respostas.respostaAluno) as soma_resposta, 
                    avg(feedback_respostas.respostaAluno) as media_satisfacao, 
                    feedback_respostas.pesquisas_perguntas_id,
                    feedback_respostas.pesquisas_alunos_id,
                    alunos_matriculas.turmas_id,
                    turmas.nomeTurma, cursos.nomeCurso, cursos.siglaCurso'
                ))
            )
            ->where([
                ['alunos_matriculas.modalidade', '=', $modalidade],
                ['turmas.statusTurma', '=', 1]
            ])
            ->whereNotIn('feedback_respostas.respostaAluno', [0, 5])
            ->whereBetween('feedback_respostas.created_at', [$dataInicial, $dataFinal])
            ->groupby([
                'feedback_respostas.disciplinas_id',
                'feedback_respostas.pesquisas_perguntas_id',
                'alunos_matriculas.turmas_id'
            ])
            ->orderBy('feedback_respostas.disciplinas_id')
            ->get();
        return $query;
    }

    public function getRelatorioMediaGeral(string $dataInicial, string $dataFinal, int $modalidade)
    {
        $query = $this->join('feedback_perguntas', 'feedback_perguntas.id', 'feedback_respostas.pesquisas_perguntas_id')
            ->select(
                'feedback_respostas.disciplinas_id',
                (DB::raw(
                    'count(feedback_respostas.id) as count_id, 
                    sum(feedback_respostas.respostaAluno) as soma_resposta, 
                    avg(feedback_respostas.respostaAluno) as media_satisfacao, 
                    feedback_respostas.pesquisas_perguntas_id,
                    feedback_respostas.pesquisas_alunos_id'
                ))
            )
            ->where([
                ['feedback_perguntas.modalidadeCurso', '=', $modalidade]
            ])
            ->whereNotIn('feedback_respostas.respostaAluno', [0, 5])
            ->whereNotNull('feedback_respostas.respostaAluno')
            ->whereBetween('feedback_respostas.created_at', [$dataInicial, $dataFinal])
            ->groupby([
                'feedback_respostas.pesquisas_perguntas_id',
            ])
            ->orderBy('feedback_respostas.disciplinas_id')
            ->get();
        return $query;
    }

    public function disciplina()
    {
        return $this->belongsTo(Disciplina::class, 'disciplinas_id');
    }

    public function feedback_pergunta()
    {
        return $this->belongsTo(FeedbackPerguntas::class, 'pesquisas_perguntas_id');
    }

    public function feedback_alunos()
    {
        return $this->belongsTo(FeedbackAlunos::class, 'pesquisas_alunos_id');
    }

    // public function getDisciplinasFeedback($dataInicial, $dataFinal, $modalidade)
    // {
    //     $query = $this->join('feedback_alunos', 'feedback_alunos.id', 'pesquisas_alunos_id')
    //         ->join('alunos_matriculas', 'alunos_matriculas.id', 'feedback_alunos.alunos_matriculas_id')
    //         ->where('alunos_matriculas.modalidade', $modalidade)
    //         ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
    //         ->join('cursos', 'cursos.id', 'turmas.cursos_id')
    //         ->whereBetween('feedback_respostas.created_at', [$dataInicial, $dataFinal])
    //         ->select('feedback_respostas.disciplinas_id', 'turmas.nomeTurma', 'cursos.siglaCurso', 'cursos.nomeCurso', 'turmas.id as turmaId')
    //         ->groupby('feedback_respostas.disciplinas_id')
    //         ->groupby('alunos_matriculas.turmas_id')
    //         ->get();
    //     return $query;
    // }

    // public function getContaFeedback(int $disciplinas_id, int $pesquisas_perguntas_id, int $turmas_id, $dataInicial, $dataFinal)
    // {
    //     $query = $this->join('feedback_alunos', 'feedback_alunos.id', 'pesquisas_alunos_id')
    //         ->join('alunos_matriculas', 'alunos_matriculas.id', 'feedback_alunos.alunos_matriculas_id')
    //         ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
    //         ->join('cursos', 'cursos.id', 'turmas.cursos_id')
    //         ->join('disciplinas', 'disciplinas.id', 'feedback_respostas.disciplinas_id')
    //         ->whereNotIn('feedback_respostas.respostaAluno', [0, 5])
    //         ->where('turmas.id', $turmas_id)
    //         ->where('feedback_respostas.pesquisas_perguntas_id', $pesquisas_perguntas_id)
    //         ->where('disciplinas_id', $disciplinas_id)
    //         ->whereBetween('feedback_respostas.created_at', [$dataInicial, $dataFinal])
    //         ->count('feedback_respostas.id');
    //     return $query;
    // }

    // public function getContaFeedbackSastifacao(int $disciplinas_id, int $pesquisas_perguntas_id, int $turmas_id, $dataInicial, $dataFinal)
    // {
    //     $query = $this->join('feedback_alunos', 'feedback_alunos.id', 'pesquisas_alunos_id')
    //         ->join('alunos_matriculas', 'alunos_matriculas.id', 'feedback_alunos.alunos_matriculas_id')
    //         ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
    //         ->join('cursos', 'cursos.id', 'turmas.cursos_id')
    //         ->join('disciplinas', 'disciplinas.id', 'feedback_respostas.disciplinas_id')
    //         ->whereIn('feedback_respostas.respostaAluno', [3, 4])
    //         ->where('turmas.id', $turmas_id)
    //         ->where('feedback_respostas.pesquisas_perguntas_id', $pesquisas_perguntas_id)
    //         ->where('disciplinas_id', $disciplinas_id)
    //         ->whereBetween('feedback_respostas.created_at', [$dataInicial, $dataFinal])
    //         ->groupby('feedback_respostas.pesquisas_perguntas_id')
    //         ->count('feedback_respostas.id');

    //     return $query;
    // }
}
