<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class PesquisasAluno extends Model
{
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = ['aulas_professores_id', 'alunos_matriculas_id', 'nivelSatisfacao', 'obsFeedback'];


    /**
     * Lista feedbacks relacionados a uma matrícula
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getFeedbacksMatricula(int $idMatricula)
    {
        return $this->join('aulas_professores', 'aulas_professores.id', 'pesquisas_alunos.aulas_professores_id')
                    ->join('disciplinas', 'disciplinas.id', 'aulas_professores.disciplinas_id')
                    ->join('users', 'users.id', 'aulas_professores.users_id')
                    ->join('aulas_salas', 'aulas_salas.id', 'aulas_professores.aulas_salas_id')
                    ->orderBy('aulas_professores.dataInicio', 'asc')
                    ->select('disciplinas.nomeDisciplna', 'users.name as nomeDocente', 'aulas_salas.nomeSala', 'aulas_professores.dataInicio', 'aulas_professores.dataFim', 'aulas_professores.horaInicio', 'aulas_professores.horaFim', 'pesquisas_alunos.*')
                    ->get();
    }


    /**
     * Consulta registro de feedback
     *
     * @param integer $idAulaProfessor
     * @param integer $idMatricula
     * @return void
     */
    public function getPesquisaModuloAluno(int $idAulaProfessor, int $idMatricula)
    {
        return $this->where('aulas_professores_id', $idAulaProfessor)
                    ->where('alunos_matriculas_id', $idMatricula)
                    ->first();
    }

    public function getPesquisaAluno(int $idPesquisa)
    {
        return $this->join('aulas_professores', 'aulas_professores.id', 'pesquisas_alunos.aulas_professores_id')
                    ->join('alunos_matriculas', 'alunos_matriculas.id', 'pesquisas_alunos.alunos_matriculas_id')
                    ->join('disciplinas', 'disciplinas.id', 'aulas_professores.disciplinas_id')
                    ->join('users', 'users.id', 'aulas_professores.users_id')
                    ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
                    ->join('cursos', 'cursos.id', 'turmas.cursos_id')
                    ->where('pesquisas_alunos.id', $idPesquisa)
                    ->select('cursos.*', 'turmas.nomeTurma', 'users.name as nomeDocente', 'disciplinas.nomeDisciplina', 'aulas_professores.dataInicio', 'aulas_professores.dataFim')
                    ->first();
    }
}
