<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class Protocolo extends Model
{
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
     protected $fillable = ['alunos_matriculas_id', 'protocolo_assuntos_id', 'codigoProtocolo', 'justificativaProtocolo', 'nivelUrgencia', 'dataPagamento', 'prazoResposta', 'emAtraso', 'statusProtocolo', 'situacaoProtocolo'];

    /**
     * Lista Protocolos pelo ID da Matrícula
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getProtocolosMatricula(int $idMatricula)
    {
        return $this->join('protocolos_assuntos', 'protocolos_assuntos.id', 'protocolos.protocolo_assuntos_id')
                    ->join('alunos_faturas', 'alunos_faturas.codFatura', 'protocolos.codigoProtocolo')
                    ->where('protocolos.alunos_matriculas_id', $idMatricula)
                    ->orderBy('created_at', 'asc')
                    ->select('alunos_faturas.id as idBoleto', 'alunos_faturas.registradaBco', 'alunos_faturas.statusFatura', 'alunos_faturas.dataVcto as vctoBoleto', 'alunos_faturas.valorFatura', 'protocolos.*', 'protocolos.prazoResposta as dataVcto', 'protocolos_assuntos.tituloAssunto', 'protocolos_assuntos.prazoResposta', 'protocolos_assuntos.valorProtocolo')
                    ->get();
    }

    /**
     * Lista Dados de um determinado protocolo
     *
     * @param integer $id
     * @return void
     */
    public function getProtocoloID(int $id)
    {
        return $this->join('protocolos_assuntos', 'protocolos_assuntos.id', 'protocolos.protocolo_assuntos_id')
                    ->join('alunos_faturas', 'alunos_faturas.codFatura', 'protocolos.codigoProtocolo')
                    ->where('protocolos.id', $id)
                    ->orderBy('created_at', 'asc')
                    ->select('alunos_faturas.id as idBoleto', 'alunos_faturas.valorFatura', 'protocolos.*', 'protocolos.prazoResposta as dataVcto', 'protocolos_assuntos.tituloAssunto', 'protocolos_assuntos.prazoResposta', 'protocolos_assuntos.valorProtocolo')
                    ->first();
    }
}
